# Standard Library
from datetime import datetime as DT
from json import loads
from time import localtime, timezone


class InvalidSAME(Exception):
    def __init__(self, error, message="Invalid Data in SAME Message"):
        self.message = message
        self.error = error
        super().__init__(self.message)

    def __str__(self):
        return f"{self.message}: {self.error}"


class MissingSAME(Exception):
    def __init__(self, message="Missing SAME Message"):
        self.message = message
        super().__init__(self.message)

    def __str__(self):
        return f"{self.message}"


class EAS2Text(object):

    __data__ = """{"SAME":{"01001":"Autauga County, AL","01003":"Baldwin County, AL","01005":"Barbour County, AL","01007":"Bibb County, AL","01009":"Blount County, AL","01011":"Bullock County, AL","01013":"Butler County, AL","01015":"Calhoun County, AL","01017":"Chambers County, AL","01019":"Cherokee County, AL","01021":"Chilton County, AL","01023":"Choctaw County, AL","01025":"Clarke County, AL","01027":"Clay County, AL","01029":"Cleburne County, AL","01031":"Coffee County, AL","01033":"Colbert County, AL","01035":"Conecuh County, AL","01037":"Coosa County, AL","01039":"Covington County, AL","01041":"Crenshaw County, AL","01043":"Cullman County, AL","01045":"Dale County, AL","01047":"Dallas County, AL","01049":"DeKalb County, AL","01051":"Elmore County, AL","01053":"Escambia County, AL","01055":"Etowah County, AL","01057":"Fayette County, AL","01059":"Franklin County, AL","01061":"Geneva County, AL","01063":"Greene County, AL","01065":"Hale County, AL","01067":"Henry County, AL","01069":"Houston County, AL","01071":"Jackson County, AL","01073":"Jefferson County, AL","01075":"Lamar County, AL","01077":"Lauderdale County, AL","01079":"Lawrence County, AL","01081":"Lee County, AL","01083":"Limestone County, AL","01085":"Lowndes County, AL","01087":"Macon County, AL","01089":"Madison County, AL","01091":"Marengo County, AL","01093":"Marion County, AL","01095":"Marshall County, AL","01097":"Mobile County, AL","01099":"Monroe County, AL","01101":"Montgomery County, AL","01103":"Morgan County, AL","01105":"Perry County, AL","01107":"Pickens County, AL","01109":"Pike County, AL","01111":"Randolph County, AL","01113":"Russell County, AL","01115":"St. Clair County, AL","01117":"Shelby County, AL","01119":"Sumter County, AL","01121":"Talladega County, AL","01123":"Tallapoosa County, AL","01125":"Tuscaloosa County, AL","01127":"Walker County, AL","01129":"Washington County, AL","01131":"Wilcox County, AL","01133":"Winston County, AL","02013":"Aleutians East County, AK","02016":"Aleutians West County, AK","02020":"Anchorage County, AK","02050":"Bethel County, AK","02060":"Bristol Bay County, AK","02068":"Denali County, AK","02070":"Dillingham County, AK","02090":"Fairbanks N Star County, AK","02100":"Haines County, AK","02110":"Juneau County, AK","02122":"Kenai Peninsula County, AK","02130":"Ketchikan Gateway County, AK","02150":"Kodiak Island County, AK","02164":"Lake and Peninsula County, AK","02170":"Matanuska-Susitna County, AK","02180":"Nome County, AK","02185":"North Slope County, AK","02188":"Northwest Arctic County, AK","02201":"Prince of Wales-Outer Ketchikan County, AK","02220":"Sitka County, AK","02232":"Skagway-Hoonah-Angoon County, AK","02240":"Southeast Fairbanks County, AK","02261":"Valdez-Cordova County, AK","02270":"Wade Hampton County, AK","02280":"Wrangell-Petersburg County, AK","02282":"Yakutat County, AK","02290":"Yukon-Koyukuk County, AK","04001":"Apache County, AZ","04003":"Cochise County, AZ","04005":"Coconino County, AZ","04007":"Gila County, AZ","04009":"Graham County, AZ","04011":"Greenlee County, AZ","04012":"La Paz County, AZ","04013":"Maricopa County, AZ","04015":"Mohave County, AZ","04017":"Navajo County, AZ","04019":"Pima County, AZ","04021":"Pinal County, AZ","04023":"Santa Cruz County, AZ","04025":"Yavapai County, AZ","04027":"Yuma County, AZ","05001":"Arkansas County, AR","05003":"Ashley County, AR","05005":"Baxter County, AR","05007":"Benton County, AR","05009":"Boone County, AR","05011":"Bradley County, AR","05013":"Calhoun County, AR","05015":"Carroll County, AR","05017":"Chicot County, AR","05019":"Clark County, AR","05021":"Clay County, AR","05023":"Cleburne County, AR","05025":"Cleveland County, AR","05027":"Columbia County, AR","05029":"Conway County, AR","05031":"Craighead County, AR","05033":"Crawford County, AR","05035":"Crittenden County, AR","05037":"Cross County, AR","05039":"Dallas County, AR","05041":"Desha County, AR","05043":"Drew County, AR","05045":"Faulkner County, AR","05047":"Franklin County, AR","05049":"Fulton County, AR","05051":"Garland County, AR","05053":"Grant County, AR","05055":"Greene County, AR","05057":"Hempstead County, AR","05059":"Hot Spring County, AR","05061":"Howard County, AR","05063":"Independence County, AR","05065":"Izard County, AR","05067":"Jackson County, AR","05069":"Jefferson County, AR","05071":"Johnson County, AR","05073":"Lafayette County, AR","05075":"Lawrence County, AR","05077":"Lee County, AR","05079":"Lincoln County, AR","05081":"Little River County, AR","05083":"Logan County, AR","05085":"Lonoke County, AR","05087":"Madison County, AR","05089":"Marion County, AR","05091":"Miller County, AR","05093":"Mississippi County, AR","05095":"Monroe County, AR","05097":"Montgomery County, AR","05099":"Nevada County, AR","05101":"Newton County, AR","05103":"Ouachita County, AR","05105":"Perry County, AR","05107":"Phillips County, AR","05109":"Pike County, AR","05111":"Poinsett County, AR","05113":"Polk County, AR","05115":"Pope County, AR","05117":"Prairie County, AR","05119":"Pulaski County, AR","05121":"Randolph County, AR","05123":"St. Francis County, AR","05125":"Saline County, AR","05127":"Scott County, AR","05129":"Searcy County, AR","05131":"Sebastian County, AR","05133":"Sevier County, AR","05135":"Sharp County, AR","05137":"Stone County, AR","05139":"Union County, AR","05141":"Van Buren County, AR","05143":"Washington County, AR","05145":"White County, AR","05147":"Woodruff County, AR","05149":"Yell County, AR","06001":"Alameda County, CA","06003":"Alpine County, CA","06005":"Amador County, CA","06007":"Butte County, CA","06009":"Calaveras County, CA","06011":"Colusa County, CA","06013":"Contra Costa County, CA","06015":"Del Norte County, CA","06017":"El Dorado County, CA","06019":"Fresno County, CA","06021":"Glenn County, CA","06023":"Humboldt County, CA","06025":"Imperial County, CA","06027":"Inyo County, CA","06029":"Kern County, CA","06031":"Kings County, CA","06033":"Lake County, CA","06035":"Lassen County, CA","06037":"Los Angeles County, CA","06039":"Madera County, CA","06041":"Marin County, CA","06043":"Mariposa County, CA","06045":"Mendocino County, CA","06047":"Merced County, CA","06049":"Modoc County, CA","06051":"Mono County, CA","06053":"Monterey County, CA","06055":"Napa County, CA","06057":"Nevada County, CA","06059":"Orange County, CA","06061":"Placer County, CA","06063":"Plumas County, CA","06065":"Riverside County, CA","06067":"Sacramento County, CA","06069":"San Benito County, CA","06071":"San Bernardino County, CA","06073":"San Diego County, CA","06075":"San Francisco County, CA","06077":"San Joaquin County, CA","06079":"San Luis Obispo County, CA","06081":"San Mateo County, CA","06083":"Santa Barbara County, CA","06085":"Santa Clara County, CA","06087":"Santa Cruz County, CA","06089":"Shasta County, CA","06091":"Sierra County, CA","06093":"Siskiyou County, CA","06095":"Solano County, CA","06097":"Sonoma County, CA","06099":"Stanislaus County, CA","06101":"Sutter County, CA","06103":"Tehama County, CA","06105":"Trinity County, CA","06107":"Tulare County, CA","06109":"Tuolumne County, CA","06111":"Ventura County, CA","06113":"Yolo County, CA","06115":"Yuba County, CA","08001":"Adams County, CO","08003":"Alamosa County, CO","08005":"Arapahoe County, CO","08007":"Archuleta County, CO","08009":"Baca County, CO","08011":"Bent County, CO","08013":"Boulder County, CO","08014":"Broomfield County, CO","08015":"Chaffee County, CO","08017":"Cheyenne County, CO","08019":"Clear Creek County, CO","08021":"Conejos County, CO","08023":"Costilla County, CO","08025":"Crowley County, CO","08027":"Custer County, CO","08029":"Delta County, CO","08031":"Denver County, CO","08033":"Dolores County, CO","08035":"Douglas County, CO","08037":"Eagle County, CO","08039":"Elbert County, CO","08041":"El Paso County, CO","08043":"Fremont County, CO","08045":"Garfield County, CO","08047":"Gilpin County, CO","08049":"Grand County, CO","08051":"Gunnison County, CO","08053":"Hinsdale County, CO","08055":"Huerfano County, CO","08057":"Jackson County, CO","08059":"Jefferson County, CO","08061":"Kiowa County, CO","08063":"Kit Carson County, CO","08065":"Lake County, CO","08067":"La Plata County, CO","08069":"Larimer County, CO","08071":"Las Animas County, CO","08073":"Lincoln County, CO","08075":"Logan County, CO","08077":"Mesa County, CO","08079":"Mineral County, CO","08081":"Moffat County, CO","08083":"Montezuma County, CO","08085":"Montrose County, CO","08087":"Morgan County, CO","08089":"Otero County, CO","08091":"Ouray County, CO","08093":"Park County, CO","08095":"Phillips County, CO","08097":"Pitkin County, CO","08099":"Prowers County, CO","08101":"Pueblo County, CO","08103":"Rio Blanco County, CO","08105":"Rio Grande County, CO","08107":"Routt County, CO","08109":"Saguache County, CO","08111":"San Juan County, CO","08113":"San Miguel County, CO","08115":"Sedgwick County, CO","08117":"Summit County, CO","08119":"Teller County, CO","08121":"Washington County, CO","08123":"Weld County, CO","08125":"Yuma County, CO","09001":"Fairfield County, CT","09003":"Hartford County, CT","09005":"Litchfield County, CT","09007":"Middlesex County, CT","09009":"New Haven County, CT","09011":"New London County, CT","09013":"Tolland County, CT","09015":"Windham County, CT","10001":"Kent County, DE","10003":"New Castle County, DE","10005":"Sussex County, DE","11001":"Washington, DC","12001":"Alachua County, FL","12003":"Baker County, FL","12005":"Bay County, FL","12007":"Bradford County, FL","12009":"Brevard County, FL","12011":"Broward County, FL","12013":"Calhoun County, FL","12015":"Charlotte County, FL","12017":"Citrus County, FL","12019":"Clay County, FL","12021":"Collier County, FL","12023":"Columbia County, FL","12027":"DeSoto County, FL","12029":"Dixie County, FL","12031":"Duval County, FL","12033":"Escambia County, FL","12035":"Flagler County, FL","12037":"Franklin County, FL","12039":"Gadsden County, FL","12041":"Gilchrist County, FL","12043":"Glades County, FL","12045":"Gulf County, FL","12047":"Hamilton County, FL","12049":"Hardee County, FL","12051":"Hendry County, FL","12053":"Hernando County, FL","12055":"Highlands County, FL","12057":"Hillsborough County, FL","12059":"Holmes County, FL","12061":"Indian River County, FL","12063":"Jackson County, FL","12065":"Jefferson County, FL","12067":"Lafayette County, FL","12069":"Lake County, FL","12071":"Lee County, FL","12073":"Leon County, FL","12075":"Levy County, FL","12077":"Liberty County, FL","12079":"Madison County, FL","12081":"Manatee County, FL","12083":"Marion County, FL","12085":"Martin County, FL","12086":"Miami-Dade County, FL","12087":"Monroe County, FL","12089":"Nassau County, FL","12091":"Okaloosa County, FL","12093":"Okeechobee County, FL","12095":"Orange County, FL","12097":"Osceola County, FL","12099":"Palm Beach County, FL","12101":"Pasco County, FL","12103":"Pinellas County, FL","12105":"Polk County, FL","12107":"Putnam County, FL","12109":"St. Johns County, FL","12111":"St. Lucie County, FL","12113":"Santa Rosa County, FL","12115":"Sarasota County, FL","12117":"Seminole County, FL","12119":"Sumter County, FL","12121":"Suwannee County, FL","12123":"Taylor County, FL","12125":"Union County, FL","12127":"Volusia County, FL","12129":"Wakulla County, FL","12131":"Walton County, FL","12133":"Washington County, FL","13001":"Appling County, GA","13003":"Atkinson County, GA","13005":"Bacon County, GA","13007":"Baker County, GA","13009":"Baldwin County, GA","13011":"Banks County, GA","13013":"Barrow County, GA","13015":"Bartow County, GA","13017":"Ben Hill County, GA","13019":"Berrien County, GA","13021":"Bibb County, GA","13023":"Bleckley County, GA","13025":"Brantley County, GA","13027":"Brooks County, GA","13029":"Bryan County, GA","13031":"Bulloch County, GA","13033":"Burke County, GA","13035":"Butts County, GA","13037":"Calhoun County, GA","13039":"Camden County, GA","13043":"Candler County, GA","13045":"Carroll County, GA","13047":"Catoosa County, GA","13049":"Charlton County, GA","13051":"Chatham County, GA","13053":"Chattahoochee County, GA","13055":"Chattooga County, GA","13057":"Cherokee County, GA","13059":"Clarke County, GA","13061":"Clay County, GA","13063":"Clayton County, GA","13065":"Clinch County, GA","13067":"Cobb County, GA","13069":"Coffee County, GA","13071":"Colquitt County, GA","13073":"Columbia County, GA","13075":"Cook County, GA","13077":"Coweta County, GA","13079":"Crawford County, GA","13081":"Crisp County, GA","13083":"Dade County, GA","13085":"Dawson County, GA","13087":"Decatur County, GA","13089":"DeKalb County, GA","13091":"Dodge County, GA","13093":"Dooly County, GA","13095":"Dougherty County, GA","13097":"Douglas County, GA","13099":"Early County, GA","13101":"Echols County, GA","13103":"Effingham County, GA","13105":"Elbert County, GA","13107":"Emanuel County, GA","13109":"Evans County, GA","13111":"Fannin County, GA","13113":"Fayette County, GA","13115":"Floyd County, GA","13117":"Forsyth County, GA","13119":"Franklin County, GA","13121":"Fulton County, GA","13123":"Gilmer County, GA","13125":"Glascock County, GA","13127":"Glynn County, GA","13129":"Gordon County, GA","13131":"Grady County, GA","13133":"Greene County, GA","13135":"Gwinnett County, GA","13137":"Habersham County, GA","13139":"Hall County, GA","13141":"Hancock County, GA","13143":"Haralson County, GA","13145":"Harris County, GA","13147":"Hart County, GA","13149":"Heard County, GA","13151":"Henry County, GA","13153":"Houston County, GA","13155":"Irwin County, GA","13157":"Jackson County, GA","13159":"Jasper County, GA","13161":"Jeff Davis County, GA","13163":"Jefferson County, GA","13165":"Jenkins County, GA","13167":"Johnson County, GA","13169":"Jones County, GA","13171":"Lamar County, GA","13173":"Lanier County, GA","13175":"Laurens County, GA","13177":"Lee County, GA","13179":"Liberty County, GA","13181":"Lincoln County, GA","13183":"Long County, GA","13185":"Lowndes County, GA","13187":"Lumpkin County, GA","13189":"McDuffie County, GA","13191":"McIntosh County, GA","13193":"Macon County, GA","13195":"Madison County, GA","13197":"Marion County, GA","13199":"Meriwether County, GA","13201":"Miller County, GA","13205":"Mitchell County, GA","13207":"Monroe County, GA","13209":"Montgomery County, GA","13211":"Morgan County, GA","13213":"Murray County, GA","13215":"Muscogee County, GA","13217":"Newton County, GA","13219":"Oconee County, GA","13221":"Oglethorpe County, GA","13223":"Paulding County, GA","13225":"Peach County, GA","13227":"Pickens County, GA","13229":"Pierce County, GA","13231":"Pike County, GA","13233":"Polk County, GA","13235":"Pulaski County, GA","13237":"Putnam County, GA","13239":"Quitman County, GA","13241":"Rabun County, GA","13243":"Randolph County, GA","13245":"Richmond County, GA","13247":"Rockdale County, GA","13249":"Schley County, GA","13251":"Screven County, GA","13253":"Seminole County, GA","13255":"Spalding County, GA","13257":"Stephens County, GA","13259":"Stewart County, GA","13261":"Sumter County, GA","13263":"Talbot County, GA","13265":"Taliaferro County, GA","13267":"Tattnall County, GA","13269":"Taylor County, GA","13271":"Telfair County, GA","13273":"Terrell County, GA","13275":"Thomas County, GA","13277":"Tift County, GA","13279":"Toombs County, GA","13281":"Towns County, GA","13283":"Treutlen County, GA","13285":"Troup County, GA","13287":"Turner County, GA","13289":"Twiggs County, GA","13291":"Union County, GA","13293":"Upson County, GA","13295":"Walker County, GA","13297":"Walton County, GA","13299":"Ware County, GA","13301":"Warren County, GA","13303":"Washington County, GA","13305":"Wayne County, GA","13307":"Webster County, GA","13309":"Wheeler County, GA","13311":"White County, GA","13313":"Whitfield County, GA","13315":"Wilcox County, GA","13317":"Wilkes County, GA","13319":"Wilkinson County, GA","13321":"Worth County, GA","15001":"Hawaii County, HI","15003":"Honolulu County, HI","15005":"Kalawao County, HI","15007":"Kauai County, HI","15009":"Maui County, HI","16001":"Ada County, ID","16003":"Adams County, ID","16005":"Bannock County, ID","16007":"Bear Lake County, ID","16009":"Benewah County, ID","16011":"Bingham County, ID","16013":"Blaine County, ID","16015":"Boise County, ID","16017":"Bonner County, ID","16019":"Bonneville County, ID","16021":"Boundary County, ID","16023":"Butte County, ID","16025":"Camas County, ID","16027":"Canyon County, ID","16029":"Caribou County, ID","16031":"Cassia County, ID","16033":"Clark County, ID","16035":"Clearwater County, ID","16037":"Custer County, ID","16039":"Elmore County, ID","16041":"Franklin County, ID","16043":"Fremont County, ID","16045":"Gem County, ID","16047":"Gooding County, ID","16049":"Idaho County, ID","16051":"Jefferson County, ID","16053":"Jerome County, ID","16055":"Kootenai County, ID","16057":"Latah County, ID","16059":"Lemhi County, ID","16061":"Lewis County, ID","16063":"Lincoln County, ID","16065":"Madison County, ID","16067":"Minidoka County, ID","16069":"Nez Perce County, ID","16071":"Oneida County, ID","16073":"Owyhee County, ID","16075":"Payette County, ID","16077":"Power County, ID","16079":"Shoshone County, ID","16081":"Teton County, ID","16083":"Twin Falls County, ID","16085":"Valley County, ID","16087":"Washington County, ID","17001":"Adams County, IL","17003":"Alexander County, IL","17005":"Bond County, IL","17007":"Boone County, IL","17009":"Brown County, IL","17011":"Bureau County, IL","17013":"Calhoun County, IL","17015":"Carroll County, IL","17017":"Cass County, IL","17019":"Champaign County, IL","17021":"Christian County, IL","17023":"Clark County, IL","17025":"Clay County, IL","17027":"Clinton County, IL","17029":"Coles County, IL","17031":"Cook County, IL","17033":"Crawford County, IL","17035":"Cumberland County, IL","17037":"DeKalb County, IL","17039":"De Witt County, IL","17041":"Douglas County, IL","17043":"DuPage County, IL","17045":"Edgar County, IL","17047":"Edwards County, IL","17049":"Effingham County, IL","17051":"Fayette County, IL","17053":"Ford County, IL","17055":"Franklin County, IL","17057":"Fulton County, IL","17059":"Gallatin County, IL","17061":"Greene County, IL","17063":"Grundy County, IL","17065":"Hamilton County, IL","17067":"Hancock County, IL","17069":"Hardin County, IL","17071":"Henderson County, IL","17073":"Henry County, IL","17075":"Iroquois County, IL","17077":"Jackson County, IL","17079":"Jasper County, IL","17081":"Jefferson County, IL","17083":"Jersey County, IL","17085":"Jo Daviess County, IL","17087":"Johnson County, IL","17089":"Kane County, IL","17091":"Kankakee County, IL","17093":"Kendall County, IL","17095":"Knox County, IL","17097":"Lake County, IL","17099":"La Salle County, IL","17101":"Lawrence County, IL","17103":"Lee County, IL","17105":"Livingston County, IL","17107":"Logan County, IL","17109":"McDonough County, IL","17111":"McHenry County, IL","17113":"McLean County, IL","17115":"Macon County, IL","17117":"Macoupin County, IL","17119":"Madison County, IL","17121":"Marion County, IL","17123":"Marshall County, IL","17125":"Mason County, IL","17127":"Massac County, IL","17129":"Menard County, IL","17131":"Mercer County, IL","17133":"Monroe County, IL","17135":"Montgomery County, IL","17137":"Morgan County, IL","17139":"Moultrie County, IL","17141":"Ogle County, IL","17143":"Peoria County, IL","17145":"Perry County, IL","17147":"Piatt County, IL","17149":"Pike County, IL","17151":"Pope County, IL","17153":"Pulaski County, IL","17155":"Putnam County, IL","17157":"Randolph County, IL","17159":"Richland County, IL","17161":"Rock Island County, IL","17163":"St. Clair County, IL","17165":"Saline County, IL","17167":"Sangamon County, IL","17169":"Schuyler County, IL","17171":"Scott County, IL","17173":"Shelby County, IL","17175":"Stark County, IL","17177":"Stephenson County, IL","17179":"Tazewell County, IL","17181":"Union County, IL","17183":"Vermilion County, IL","17185":"Wabash County, IL","17187":"Warren County, IL","17189":"Washington County, IL","17191":"Wayne County, IL","17193":"White County, IL","17195":"Whiteside County, IL","17197":"Will County, IL","17199":"Williamson County, IL","17201":"Winnebago County, IL","17203":"Woodford County, IL","18001":"Adams County, IN","18003":"Allen County, IN","18005":"Bartholomew County, IN","18007":"Benton County, IN","18009":"Blackford County, IN","18011":"Boone County, IN","18013":"Brown County, IN","18015":"Carroll County, IN","18017":"Cass County, IN","18019":"Clark County, IN","18021":"Clay County, IN","18023":"Clinton County, IN","18025":"Crawford County, IN","18027":"Daviess County, IN","18029":"Dearborn County, IN","18031":"Decatur County, IN","18033":"De Kalb County, IN","18035":"Delaware County, IN","18037":"Dubois County, IN","18039":"Elkhart County, IN","18041":"Fayette County, IN","18043":"Floyd County, IN","18045":"Fountain County, IN","18047":"Franklin County, IN","18049":"Fulton County, IN","18051":"Gibson County, IN","18053":"Grant County, IN","18055":"Greene County, IN","18057":"Hamilton County, IN","18059":"Hancock County, IN","18061":"Harrison County, IN","18063":"Hendricks County, IN","18065":"Henry County, IN","18067":"Howard County, IN","18069":"Huntington County, IN","18071":"Jackson County, IN","18073":"Jasper County, IN","18075":"Jay County, IN","18077":"Jefferson County, IN","18079":"Jennings County, IN","18081":"Johnson County, IN","18083":"Knox County, IN","18085":"Kosciusko County, IN","18087":"Lagrange County, IN","18089":"Lake County, IN","18091":"La Porte County, IN","18093":"Lawrence County, IN","18095":"Madison County, IN","18097":"Marion County, IN","18099":"Marshall County, IN","18101":"Martin County, IN","18103":"Miami County, IN","18105":"Monroe County, IN","18107":"Montgomery County, IN","18109":"Morgan County, IN","18111":"Newton County, IN","18113":"Noble County, IN","18115":"Ohio County, IN","18117":"Orange County, IN","18119":"Owen County, IN","18121":"Parke County, IN","18123":"Perry County, IN","18125":"Pike County, IN","18127":"Porter County, IN","18129":"Posey County, IN","18131":"Pulaski County, IN","18133":"Putnam County, IN","18135":"Randolph County, IN","18137":"Ripley County, IN","18139":"Rush County, IN","18141":"St. Joseph County, IN","18143":"Scott County, IN","18145":"Shelby County, IN","18147":"Spencer County, IN","18149":"Starke County, IN","18151":"Steuben County, IN","18153":"Sullivan County, IN","18155":"Switzerland County, IN","18157":"Tippecanoe County, IN","18159":"Tipton County, IN","18161":"Union County, IN","18163":"Vanderburgh County, IN","18165":"Vermillion County, IN","18167":"Vigo County, IN","18169":"Wabash County, IN","18171":"Warren County, IN","18173":"Warrick County, IN","18175":"Washington County, IN","18177":"Wayne County, IN","18179":"Wells County, IN","18181":"White County, IN","18183":"Whitley County, IN","19001":"Adair County, IA","19003":"Adams County, IA","19005":"Allamakee County, IA","19007":"Appanoose County, IA","19009":"Audubon County, IA","19011":"Benton County, IA","19013":"Black Hawk County, IA","19015":"Boone County, IA","19017":"Bremer County, IA","19019":"Buchanan County, IA","19021":"Buena Vista County, IA","19023":"Butler County, IA","19025":"Calhoun County, IA","19027":"Carroll County, IA","19029":"Cass County, IA","19031":"Cedar County, IA","19033":"Cerro Gordo County, IA","19035":"Cherokee County, IA","19037":"Chickasaw County, IA","19039":"Clarke County, IA","19041":"Clay County, IA","19043":"Clayton County, IA","19045":"Clinton County, IA","19047":"Crawford County, IA","19049":"Dallas County, IA","19051":"Davis County, IA","19053":"Decatur County, IA","19055":"Delaware County, IA","19057":"Des Moines County, IA","19059":"Dickinson County, IA","19061":"Dubuque County, IA","19063":"Emmet County, IA","19065":"Fayette County, IA","19067":"Floyd County, IA","19069":"Franklin County, IA","19071":"Fremont County, IA","19073":"Greene County, IA","19075":"Grundy County, IA","19077":"Guthrie County, IA","19079":"Hamilton County, IA","19081":"Hancock County, IA","19083":"Hardin County, IA","19085":"Harrison County, IA","19087":"Henry County, IA","19089":"Howard County, IA","19091":"Humboldt County, IA","19093":"Ida County, IA","19095":"Iowa County, IA","19097":"Jackson County, IA","19099":"Jasper County, IA","19101":"Jefferson County, IA","19103":"Johnson County, IA","19105":"Jones County, IA","19107":"Keokuk County, IA","19109":"Kossuth County, IA","19111":"Lee County, IA","19113":"Linn County, IA","19115":"Louisa County, IA","19117":"Lucas County, IA","19119":"Lyon County, IA","19121":"Madison County, IA","19123":"Mahaska County, IA","19125":"Marion County, IA","19127":"Marshall County, IA","19129":"Mills County, IA","19131":"Mitchell County, IA","19133":"Monona County, IA","19135":"Monroe County, IA","19137":"Montgomery County, IA","19139":"Muscatine County, IA","19141":"O\'Brien County, IA","19143":"Osceola County, IA","19145":"Page County, IA","19147":"Palo Alto County, IA","19149":"Plymouth County, IA","19151":"Pocahontas County, IA","19153":"Polk County, IA","19155":"Pottawattamie County, IA","19157":"Poweshiek County, IA","19159":"Ringgold County, IA","19161":"Sac County, IA","19163":"Scott County, IA","19165":"Shelby County, IA","19167":"Sioux County, IA","19169":"Story County, IA","19171":"Tama County, IA","19173":"Taylor County, IA","19175":"Union County, IA","19177":"Van Buren County, IA","19179":"Wapello County, IA","19181":"Warren County, IA","19183":"Washington County, IA","19185":"Wayne County, IA","19187":"Webster County, IA","19189":"Winnebago County, IA","19191":"Winneshiek County, IA","19193":"Woodbury County, IA","19195":"Worth County, IA","19197":"Wright County, IA","20001":"Allen County, KS","20003":"Anderson County, KS","20005":"Atchison County, KS","20007":"Barber County, KS","20009":"Barton County, KS","20011":"Bourbon County, KS","20013":"Brown County, KS","20015":"Butler County, KS","20017":"Chase County, KS","20019":"Chautauqua County, KS","20021":"Cherokee County, KS","20023":"Cheyenne County, KS","20025":"Clark County, KS","20027":"Clay County, KS","20029":"Cloud County, KS","20031":"Coffey County, KS","20033":"Comanche County, KS","20035":"Cowley County, KS","20037":"Crawford County, KS","20039":"Decatur County, KS","20041":"Dickinson County, KS","20043":"Doniphan County, KS","20045":"Douglas County, KS","20047":"Edwards County, KS","20049":"Elk County, KS","20051":"Ellis County, KS","20053":"Ellsworth County, KS","20055":"Finney County, KS","20057":"Ford County, KS","20059":"Franklin County, KS","20061":"Geary County, KS","20063":"Gove County, KS","20065":"Graham County, KS","20067":"Grant County, KS","20069":"Gray County, KS","20071":"Greeley County, KS","20073":"Greenwood County, KS","20075":"Hamilton County, KS","20077":"Harper County, KS","20079":"Harvey County, KS","20081":"Haskell County, KS","20083":"Hodgeman County, KS","20085":"Jackson County, KS","20087":"Jefferson County, KS","20089":"Jewell County, KS","20091":"Johnson County, KS","20093":"Kearny County, KS","20095":"Kingman County, KS","20097":"Kiowa County, KS","20099":"Labette County, KS","20101":"Lane County, KS","20103":"Leavenworth County, KS","20105":"Lincoln County, KS","20107":"Linn County, KS","20109":"Logan County, KS","20111":"Lyon County, KS","20113":"McPherson County, KS","20115":"Marion County, KS","20117":"Marshall County, KS","20119":"Meade County, KS","20121":"Miami County, KS","20123":"Mitchell County, KS","20125":"Montgomery County, KS","20127":"Morris County, KS","20129":"Morton County, KS","20131":"Nemaha County, KS","20133":"Neosho County, KS","20135":"Ness County, KS","20137":"Norton County, KS","20139":"Osage County, KS","20141":"Osborne County, KS","20143":"Ottawa County, KS","20145":"Pawnee County, KS","20147":"Phillips County, KS","20149":"Pottawatomie County, KS","20151":"Pratt County, KS","20153":"Rawlins County, KS","20155":"Reno County, KS","20157":"Republic County, KS","20159":"Rice County, KS","20161":"Riley County, KS","20163":"Rooks County, KS","20165":"Rush County, KS","20167":"Russell County, KS","20169":"Saline County, KS","20171":"Scott County, KS","20173":"Sedgwick County, KS","20175":"Seward County, KS","20177":"Shawnee County, KS","20179":"Sheridan County, KS","20181":"Sherman County, KS","20183":"Smith County, KS","20185":"Stafford County, KS","20187":"Stanton County, KS","20189":"Stevens County, KS","20191":"Sumner County, KS","20193":"Thomas County, KS","20195":"Trego County, KS","20197":"Wabaunsee County, KS","20199":"Wallace County, KS","20201":"Washington County, KS","20203":"Wichita County, KS","20205":"Wilson County, KS","20207":"Woodson County, KS","20209":"Wyandotte County, KS","21001":"Adair County, KY","21003":"Allen County, KY","21005":"Anderson County, KY","21007":"Ballard County, KY","21009":"Barren County, KY","21011":"Bath County, KY","21013":"Bell County, KY","21015":"Boone County, KY","21017":"Bourbon County, KY","21019":"Boyd County, KY","21021":"Boyle County, KY","21023":"Bracken County, KY","21025":"Breathitt County, KY","21027":"Breckinridge County, KY","21029":"Bullitt County, KY","21031":"Butler County, KY","21033":"Caldwell County, KY","21035":"Calloway County, KY","21037":"Campbell County, KY","21039":"Carlisle County, KY","21041":"Carroll County, KY","21043":"Carter County, KY","21045":"Casey County, KY","21047":"Christian County, KY","21049":"Clark County, KY","21051":"Clay County, KY","21053":"Clinton County, KY","21055":"Crittenden County, KY","21057":"Cumberland County, KY","21059":"Daviess County, KY","21061":"Edmonson County, KY","21063":"Elliott County, KY","21065":"Estill County, KY","21067":"Fayette County, KY","21069":"Fleming County, KY","21071":"Floyd County, KY","21073":"Franklin County, KY","21075":"Fulton County, KY","21077":"Gallatin County, KY","21079":"Garrard County, KY","21081":"Grant County, KY","21083":"Graves County, KY","21085":"Grayson County, KY","21087":"Green County, KY","21089":"Greenup County, KY","21091":"Hancock County, KY","21093":"Hardin County, KY","21095":"Harlan County, KY","21097":"Harrison County, KY","21099":"Hart County, KY","21101":"Henderson County, KY","21103":"Henry County, KY","21105":"Hickman County, KY","21107":"Hopkins County, KY","21109":"Jackson County, KY","21111":"Jefferson County, KY","21113":"Jessamine County, KY","21115":"Johnson County, KY","21117":"Kenton County, KY","21119":"Knott County, KY","21121":"Knox County, KY","21123":"Larue County, KY","21125":"Laurel County, KY","21127":"Lawrence County, KY","21129":"Lee County, KY","21131":"Leslie County, KY","21133":"Letcher County, KY","21135":"Lewis County, KY","21137":"Lincoln County, KY","21139":"Livingston County, KY","21141":"Logan County, KY","21143":"Lyon County, KY","21145":"McCracken County, KY","21147":"McCreary County, KY","21149":"McLean County, KY","21151":"Madison County, KY","21153":"Magoffin County, KY","21155":"Marion County, KY","21157":"Marshall County, KY","21159":"Martin County, KY","21161":"Mason County, KY","21163":"Meade County, KY","21165":"Menifee County, KY","21167":"Mercer County, KY","21169":"Metcalfe County, KY","21171":"Monroe County, KY","21173":"Montgomery County, KY","21175":"Morgan County, KY","21177":"Muhlenberg County, KY","21179":"Nelson County, KY","21181":"Nicholas County, KY","21183":"Ohio County, KY","21185":"Oldham County, KY","21187":"Owen County, KY","21189":"Owsley County, KY","21191":"Pendleton County, KY","21193":"Perry County, KY","21195":"Pike County, KY","21197":"Powell County, KY","21199":"Pulaski County, KY","21201":"Robertson County, KY","21203":"Rockcastle County, KY","21205":"Rowan County, KY","21207":"Russell County, KY","21209":"Scott County, KY","21211":"Shelby County, KY","21213":"Simpson County, KY","21215":"Spencer County, KY","21217":"Taylor County, KY","21219":"Todd County, KY","21221":"Trigg County, KY","21223":"Trimble County, KY","21225":"Union County, KY","21227":"Warren County, KY","21229":"Washington County, KY","21231":"Wayne County, KY","21233":"Webster County, KY","21235":"Whitley County, KY","21237":"Wolfe County, KY","21239":"Woodford County, KY","22001":"Acadia Parish, LA","22003":"Allen Parish, LA","22005":"Ascension Parish, LA","22007":"Assumption Parish, LA","22009":"Avoyelles Parish, LA","22011":"Beauregard Parish, LA","22013":"Bienville Parish, LA","22015":"Bossier Parish, LA","22017":"Caddo Parish, LA","22019":"Calcasieu Parish, LA","22021":"Caldwell Parish, LA","22023":"Cameron Parish, LA","22025":"Catahoula Parish, LA","22027":"Claiborne Parish, LA","22029":"Concordia Parish, LA","22031":"De Soto Parish, LA","22033":"East Baton Rouge Parish, LA","22035":"East Carroll Parish, LA","22037":"East Feliciana Parish, LA","22039":"Evangeline Parish, LA","22041":"Franklin Parish, LA","22043":"Grant Parish, LA","22045":"Iberia Parish, LA","22047":"Iberville Parish, LA","22049":"Jackson Parish, LA","22051":"Jefferson Parish, LA","22053":"Jefferson Davis Parish, LA","22055":"Lafayette Parish, LA","22057":"Lafourche Parish, LA","22059":"La Salle Parish, LA","22061":"Lincoln Parish, LA","22063":"Livingston Parish, LA","22065":"Madison Parish, LA","22067":"Morehouse Parish, LA","22069":"Natchitoches Parish, LA","22071":"Orleans Parish, LA","22073":"Ouachita Parish, LA","22075":"Plaquemines Parish, LA","22077":"Pointe Coupee Parish, LA","22079":"Rapides Parish, LA","22081":"Red River Parish, LA","22083":"Richland Parish, LA","22085":"Sabine Parish, LA","22087":"St. Bernard Parish, LA","22089":"St. Charles Parish, LA","22091":"St. Helena Parish, LA","22093":"St. James Parish, LA","22095":"St. John the Baptist Parish, LA","22097":"St. Landry Parish, LA","22099":"St. Martin Parish, LA","22101":"St. Mary Parish, LA","22103":"St. Tammany Parish, LA","22105":"Tangipahoa Parish, LA","22107":"Tensas Parish, LA","22109":"Terrebonne Parish, LA","22111":"Union Parish, LA","22113":"Vermilion Parish, LA","22115":"Vernon Parish, LA","22117":"Washington Parish, LA","22119":"Webster Parish, LA","22121":"West Baton Rouge Parish, LA","22123":"West Carroll Parish, LA","22125":"West Feliciana Parish, LA","22127":"Winn Parish, LA","23001":"Androscoggin County, ME","23003":"Aroostook County, ME","23005":"Cumberland County, ME","23007":"Franklin County, ME","23009":"Hancock County, ME","23011":"Kennebec County, ME","23013":"Knox County, ME","23015":"Lincoln County, ME","23017":"Oxford County, ME","23019":"Penobscot County, ME","23021":"Piscataquis County, ME","23023":"Sagadahoc County, ME","23025":"Somerset County, ME","23027":"Waldo County, ME","23029":"Washington County, ME","23031":"York County, ME","24001":"Allegany, MD","24003":"Anne Arundel, MD","24005":"Baltimore county, MD","24009":"Calvert, MD","24011":"Caroline, MD","24013":"Carroll, MD","24015":"Cecil, MD","24017":"Charles, MD","24019":"Dorchester, MD","24021":"Frederick, MD","24023":"Garrett, MD","24025":"Harford, MD","24027":"Howard, MD","24029":"Kent, MD","24031":"Montgomery, MD","24033":"Prince George\'s, MD","24035":"Queen Anne\'s, MD","24037":"St. Mary\'s, MD","24039":"Somerset, MD","24041":"Talbot, MD","24043":"Washington, MD","24045":"Wicomico, MD","24047":"Worcester, MD","24510":"City of Baltimore, MD","25001":"Barnstable County, MA","25003":"Berkshire County, MA","25005":"Bristol County, MA","25007":"Dukes County, MA","25009":"Essex County, MA","25011":"Franklin County, MA","25013":"Hampden County, MA","25015":"Hampshire County, MA","25017":"Middlesex County, MA","25019":"Nantucket County, MA","25021":"Norfolk County, MA","25023":"Plymouth County, MA","25025":"Suffolk County, MA","25027":"Worcester County, MA","26001":"Alcona County, MI","26003":"Alger County, MI","26005":"Allegan County, MI","26007":"Alpena County, MI","26009":"Antrim County, MI","26011":"Arenac County, MI","26013":"Baraga County, MI","26015":"Barry County, MI","26017":"Bay County, MI","26019":"Benzie County, MI","26021":"Berrien County, MI","26023":"Branch County, MI","26025":"Calhoun County, MI","26027":"Cass County, MI","26029":"Charlevoix County, MI","26031":"Cheboygan County, MI","26033":"Chippewa County, MI","26035":"Clare County, MI","26037":"Clinton County, MI","26039":"Crawford County, MI","26041":"Delta County, MI","26043":"Dickinson County, MI","26045":"Eaton County, MI","26047":"Emmet County, MI","26049":"Genesee County, MI","26051":"Gladwin County, MI","26053":"Gogebic County, MI","26055":"Grand Traverse County, MI","26057":"Gratiot County, MI","26059":"Hillsdale County, MI","26061":"Houghton County, MI","26063":"Huron County, MI","26065":"Ingham County, MI","26067":"Ionia County, MI","26069":"Iosco County, MI","26071":"Iron County, MI","26073":"Isabella County, MI","26075":"Jackson County, MI","26077":"Kalamazoo County, MI","26079":"Kalkaska County, MI","26081":"Kent County, MI","26083":"Keweenaw County, MI","26085":"Lake County, MI","26087":"Lapeer County, MI","26089":"Leelanau County, MI","26091":"Lenawee County, MI","26093":"Livingston County, MI","26095":"Luce County, MI","26097":"Mackinac County, MI","26099":"Macomb County, MI","26101":"Manistee County, MI","26103":"Marquette County, MI","26105":"Mason County, MI","26107":"Mecosta County, MI","26109":"Menominee County, MI","26111":"Midland County, MI","26113":"Missaukee County, MI","26115":"Monroe County, MI","26117":"Montcalm County, MI","26119":"Montmorency County, MI","26121":"Muskegon County, MI","26123":"Newaygo County, MI","26125":"Oakland County, MI","26127":"Oceana County, MI","26129":"Ogemaw County, MI","26131":"Ontonagon County, MI","26133":"Osceola County, MI","26135":"Oscoda County, MI","26137":"Otsego County, MI","26139":"Ottawa County, MI","26141":"Presque Isle County, MI","26143":"Roscommon County, MI","26145":"Saginaw County, MI","26147":"St. Clair County, MI","26149":"St. Joseph County, MI","26151":"Sanilac County, MI","26153":"Schoolcraft County, MI","26155":"Shiawassee County, MI","26157":"Tuscola County, MI","26159":"Van Buren County, MI","26161":"Washtenaw County, MI","26163":"Wayne County, MI","26165":"Wexford County, MI","27001":"Aitkin County, MN","27003":"Anoka County, MN","27005":"Becker County, MN","27007":"Beltrami County, MN","27009":"Benton County, MN","27011":"Big Stone County, MN","27013":"Blue Earth County, MN","27015":"Brown County, MN","27017":"Carlton County, MN","27019":"Carver County, MN","27021":"Cass County, MN","27023":"Chippewa County, MN","27025":"Chisago County, MN","27027":"Clay County, MN","27029":"Clearwater County, MN","27031":"Cook County, MN","27033":"Cottonwood County, MN","27035":"Crow Wing County, MN","27037":"Dakota County, MN","27039":"Dodge County, MN","27041":"Douglas County, MN","27043":"Faribault County, MN","27045":"Fillmore County, MN","27047":"Freeborn County, MN","27049":"Goodhue County, MN","27051":"Grant County, MN","27053":"Hennepin County, MN","27055":"Houston County, MN","27057":"Hubbard County, MN","27059":"Isanti County, MN","27061":"Itasca County, MN","27063":"Jackson County, MN","27065":"Kanabec County, MN","27067":"Kandiyohi County, MN","27069":"Kittson County, MN","27071":"Koochiching County, MN","27073":"Lac qui Parle County, MN","27075":"Lake County, MN","27077":"Lake of the Woods County, MN","27079":"Le Sueur County, MN","27081":"Lincoln County, MN","27083":"Lyon County, MN","27085":"McLeod County, MN","27087":"Mahnomen County, MN","27089":"Marshall County, MN","27091":"Martin County, MN","27093":"Meeker County, MN","27095":"Mille Lacs County, MN","27097":"Morrison County, MN","27099":"Mower County, MN","27101":"Murray County, MN","27103":"Nicollet County, MN","27105":"Nobles County, MN","27107":"Norman County, MN","27109":"Olmsted County, MN","27111":"Otter Tail County, MN","27113":"Pennington County, MN","27115":"Pine County, MN","27117":"Pipestone County, MN","27119":"Polk County, MN","27121":"Pope County, MN","27123":"Ramsey County, MN","27125":"Red Lake County, MN","27127":"Redwood County, MN","27129":"Renville County, MN","27131":"Rice County, MN","27133":"Rock County, MN","27135":"Roseau County, MN","27137":"St. Louis County, MN","27139":"Scott County, MN","27141":"Sherburne County, MN","27143":"Sibley County, MN","27145":"Stearns County, MN","27147":"Steele County, MN","27149":"Stevens County, MN","27151":"Swift County, MN","27153":"Todd County, MN","27155":"Traverse County, MN","27157":"Wabasha County, MN","27159":"Wadena County, MN","27161":"Waseca County, MN","27163":"Washington County, MN","27165":"Watonwan County, MN","27167":"Wilkin County, MN","27169":"Winona County, MN","27171":"Wright County, MN","27173":"Yellow Medicine County, MN","28001":"Adams County, MS","28003":"Alcorn County, MS","28005":"Amite County, MS","28007":"Attala County, MS","28009":"Benton County, MS","28011":"Bolivar County, MS","28013":"Calhoun County, MS","28015":"Carroll County, MS","28017":"Chickasaw County, MS","28019":"Choctaw County, MS","28021":"Claiborne County, MS","28023":"Clarke County, MS","28025":"Clay County, MS","28027":"Coahoma County, MS","28029":"Copiah County, MS","28031":"Covington County, MS","28033":"DeSoto County, MS","28035":"Forrest County, MS","28037":"Franklin County, MS","28039":"George County, MS","28041":"Greene County, MS","28043":"Grenada County, MS","28045":"Hancock County, MS","28047":"Harrison County, MS","28049":"Hinds County, MS","28051":"Holmes County, MS","28053":"Humphreys County, MS","28055":"Issaquena County, MS","28057":"Itawamba County, MS","28059":"Jackson County, MS","28061":"Jasper County, MS","28063":"Jefferson County, MS","28065":"Jefferson Davis County, MS","28067":"Jones County, MS","28069":"Kemper County, MS","28071":"Lafayette County, MS","28073":"Lamar County, MS","28075":"Lauderdale County, MS","28077":"Lawrence County, MS","28079":"Leake County, MS","28081":"Lee County, MS","28083":"Leflore County, MS","28085":"Lincoln County, MS","28087":"Lowndes County, MS","28089":"Madison County, MS","28091":"Marion County, MS","28093":"Marshall County, MS","28095":"Monroe County, MS","28097":"Montgomery County, MS","28099":"Neshoba County, MS","28101":"Newton County, MS","28103":"Noxubee County, MS","28105":"Oktibbeha County, MS","28107":"Panola County, MS","28109":"Pearl River County, MS","28111":"Perry County, MS","28113":"Pike County, MS","28115":"Pontotoc County, MS","28117":"Prentiss County, MS","28119":"Quitman County, MS","28121":"Rankin County, MS","28123":"Scott County, MS","28125":"Sharkey County, MS","28127":"Simpson County, MS","28129":"Smith County, MS","28131":"Stone County, MS","28133":"Sunflower County, MS","28135":"Tallahatchie County, MS","28137":"Tate County, MS","28139":"Tippah County, MS","28141":"Tishomingo County, MS","28143":"Tunica County, MS","28145":"Union County, MS","28147":"Walthall County, MS","28149":"Warren County, MS","28151":"Washington County, MS","28153":"Wayne County, MS","28155":"Webster County, MS","28157":"Wilkinson County, MS","28159":"Winston County, MS","28161":"Yalobusha County, MS","28163":"Yazoo County, MS","29001":"Adair County, MO","29003":"Andrew County, MO","29005":"Atchison County, MO","29007":"Audrain County, MO","29009":"Barry County, MO","29011":"Barton County, MO","29013":"Bates County, MO","29015":"Benton County, MO","29017":"Bollinger County, MO","29019":"Boone County, MO","29021":"Buchanan County, MO","29023":"Butler County, MO","29025":"Caldwell County, MO","29027":"Callaway County, MO","29029":"Camden County, MO","29031":"Cape Girardeau County, MO","29033":"Carroll County, MO","29035":"Carter County, MO","29037":"Cass County, MO","29039":"Cedar County, MO","29041":"Chariton County, MO","29043":"Christian County, MO","29045":"Clark County, MO","29047":"Clay County, MO","29049":"Clinton County, MO","29051":"Cole County, MO","29053":"Cooper County, MO","29055":"Crawford County, MO","29057":"Dade County, MO","29059":"Dallas County, MO","29061":"Daviess County, MO","29063":"DeKalb County, MO","29065":"Dent County, MO","29067":"Douglas County, MO","29069":"Dunklin County, MO","29071":"Franklin County, MO","29073":"Gasconade County, MO","29075":"Gentry County, MO","29077":"Greene County, MO","29079":"Grundy County, MO","29081":"Harrison County, MO","29083":"Henry County, MO","29085":"Hickory County, MO","29087":"Holt County, MO","29089":"Howard County, MO","29091":"Howell County, MO","29093":"Iron County, MO","29095":"Jackson County, MO","29097":"Jasper County, MO","29099":"Jefferson County, MO","29101":"Johnson County, MO","29103":"Knox County, MO","29105":"Laclede County, MO","29107":"Lafayette County, MO","29109":"Lawrence County, MO","29111":"Lewis County, MO","29113":"Lincoln County, MO","29115":"Linn County, MO","29117":"Livingston County, MO","29119":"McDonald County, MO","29121":"Macon County, MO","29123":"Madison County, MO","29125":"Maries County, MO","29127":"Marion County, MO","29129":"Mercer County, MO","29131":"Miller County, MO","29133":"Mississippi County, MO","29135":"Moniteau County, MO","29137":"Monroe County, MO","29139":"Montgomery County, MO","29141":"Morgan County, MO","29143":"New Madrid County, MO","29145":"Newton County, MO","29147":"Nodaway County, MO","29149":"Oregon County, MO","29151":"Osage County, MO","29153":"Ozark County, MO","29155":"Pemiscot County, MO","29157":"Perry County, MO","29159":"Pettis County, MO","29161":"Phelps County, MO","29163":"Pike County, MO","29165":"Platte County, MO","29167":"Polk County, MO","29169":"Pulaski County, MO","29171":"Putnam County, MO","29173":"Ralls County, MO","29175":"Randolph County, MO","29177":"Ray County, MO","29179":"Reynolds County, MO","29181":"Ripley County, MO","29183":"St. Charles County, MO","29185":"St. Clair County, MO","29186":"Ste. Genevieve County, MO","29187":"St. Francois County, MO","29189":"St. Louis County, MO","29195":"Saline County, MO","29197":"Schuyler County, MO","29199":"Scotland County, MO","29201":"Scott County, MO","29203":"Shannon County, MO","29205":"Shelby County, MO","29207":"Stoddard County, MO","29209":"Stone County, MO","29211":"Sullivan County, MO","29213":"Taney County, MO","29215":"Texas County, MO","29217":"Vernon County, MO","29219":"Warren County, MO","29221":"Washington County, MO","29223":"Wayne County, MO","29225":"Webster County, MO","29227":"Worth County, MO","29229":"Wright County, MO","29510":"St. Louis County, MO","30001":"Beaverhead County, MT","30003":"Big Horn County, MT","30005":"Blaine County, MT","30007":"Broadwater County, MT","30009":"Carbon County, MT","30011":"Carter County, MT","30013":"Cascade County, MT","30015":"Chouteau County, MT","30017":"Custer County, MT","30019":"Daniels County, MT","30021":"Dawson County, MT","30023":"Deer Lodge County, MT","30025":"Fallon County, MT","30027":"Fergus County, MT","30029":"Flathead County, MT","30031":"Gallatin County, MT","30033":"Garfield County, MT","30035":"Glacier County, MT","30037":"Golden Valley County, MT","30039":"Granite County, MT","30041":"Hill County, MT","30043":"Jefferson County, MT","30045":"Judith Basin County, MT","30047":"Lake County, MT","30049":"Lewis and Clark County, MT","30051":"Liberty County, MT","30053":"Lincoln County, MT","30055":"McCone County, MT","30057":"Madison County, MT","30059":"Meagher County, MT","30061":"Mineral County, MT","30063":"Missoula County, MT","30065":"Musselshell County, MT","30067":"Park County, MT","30069":"Petroleum County, MT","30071":"Phillips County, MT","30073":"Pondera County, MT","30075":"Powder River County, MT","30077":"Powell County, MT","30079":"Prairie County, MT","30081":"Ravalli County, MT","30083":"Richland County, MT","30085":"Roosevelt County, MT","30087":"Rosebud County, MT","30089":"Sanders County, MT","30091":"Sheridan County, MT","30093":"Silver Bow County, MT","30095":"Stillwater County, MT","30097":"Sweet Grass County, MT","30099":"Teton County, MT","30101":"Toole County, MT","30103":"Treasure County, MT","30105":"Valley County, MT","30107":"Wheatland County, MT","30109":"Wibaux County, MT","30111":"Yellowstone County, MT","31001":"Adams County, NE","31003":"Antelope County, NE","31005":"Arthur County, NE","31007":"Banner County, NE","31009":"Blaine County, NE","31011":"Boone County, NE","31013":"Box Butte County, NE","31015":"Boyd County, NE","31017":"Brown County, NE","31019":"Buffalo County, NE","31021":"Burt County, NE","31023":"Butler County, NE","31025":"Cass County, NE","31027":"Cedar County, NE","31029":"Chase County, NE","31031":"Cherry County, NE","31033":"Cheyenne County, NE","31035":"Clay County, NE","31037":"Colfax County, NE","31039":"Cuming County, NE","31041":"Custer County, NE","31043":"Dakota County, NE","31045":"Dawes County, NE","31047":"Dawson County, NE","31049":"Deuel County, NE","31051":"Dixon County, NE","31053":"Dodge County, NE","31055":"Douglas County, NE","31057":"Dundy County, NE","31059":"Fillmore County, NE","31061":"Franklin County, NE","31063":"Frontier County, NE","31065":"Furnas County, NE","31067":"Gage County, NE","31069":"Garden County, NE","31071":"Garfield County, NE","31073":"Gosper County, NE","31075":"Grant County, NE","31077":"Greeley County, NE","31079":"Hall County, NE","31081":"Hamilton County, NE","31083":"Harlan County, NE","31085":"Hayes County, NE","31087":"Hitchcock County, NE","31089":"Holt County, NE","31091":"Hooker County, NE","31093":"Howard County, NE","31095":"Jefferson County, NE","31097":"Johnson County, NE","31099":"Kearney County, NE","31101":"Keith County, NE","31103":"Keya Paha County, NE","31105":"Kimball County, NE","31107":"Knox County, NE","31109":"Lancaster County, NE","31111":"Lincoln County, NE","31113":"Logan County, NE","31115":"Loup County, NE","31117":"McPherson County, NE","31119":"Madison County, NE","31121":"Merrick County, NE","31123":"Morrill County, NE","31125":"Nance County, NE","31127":"Nemaha County, NE","31129":"Nuckolls County, NE","31131":"Otoe County, NE","31133":"Pawnee County, NE","31135":"Perkins County, NE","31137":"Phelps County, NE","31139":"Pierce County, NE","31141":"Platte County, NE","31143":"Polk County, NE","31145":"Red Willow County, NE","31147":"Richardson County, NE","31149":"Rock County, NE","31151":"Saline County, NE","31153":"Sarpy County, NE","31155":"Saunders County, NE","31157":"Scotts Bluff County, NE","31159":"Seward County, NE","31161":"Sheridan County, NE","31163":"Sherman County, NE","31165":"Sioux County, NE","31167":"Stanton County, NE","31169":"Thayer County, NE","31171":"Thomas County, NE","31173":"Thurston County, NE","31175":"Valley County, NE","31177":"Washington County, NE","31179":"Wayne County, NE","31181":"Webster County, NE","31183":"Wheeler County, NE","31185":"York County, NE","32001":"Churchill County, NV","32003":"Clark County, NV","32005":"Douglas County, NV","32007":"Elko County, NV","32009":"Esmeralda County, NV","32011":"Eureka County, NV","32013":"Humboldt County, NV","32015":"Lander County, NV","32017":"Lincoln County, NV","32019":"Lyon County, NV","32021":"Mineral County, NV","32023":"Nye County, NV","32027":"Pershing County, NV","32029":"Storey County, NV","32031":"Washoe County, NV","32033":"White Pine County, NV","32510":"Carson County, NV","33001":"Belknap County, NH","33003":"Carroll County, NH","33005":"Cheshire County, NH","33007":"Coos County, NH","33009":"Grafton County, NH","33011":"Hillsborough County, NH","33013":"Merrimack County, NH","33015":"Rockingham County, NH","33017":"Strafford County, NH","33019":"Sullivan County, NH","34001":"Atlantic County, NJ","34003":"Bergen County, NJ","34005":"Burlington County, NJ","34007":"Camden County, NJ","34009":"Cape May County, NJ","34011":"Cumberland County, NJ","34013":"Essex County, NJ","34015":"Gloucester County, NJ","34017":"Hudson County, NJ","34019":"Hunterdon County, NJ","34021":"Mercer County, NJ","34023":"Middlesex County, NJ","34025":"Monmouth County, NJ","34027":"Morris County, NJ","34029":"Ocean County, NJ","34031":"Passaic County, NJ","34033":"Salem County, NJ","34035":"Somerset County, NJ","34037":"Sussex County, NJ","34039":"Union County, NJ","34041":"Warren County, NJ","35001":"Bernalillo County, NM","35003":"Catron County, NM","35005":"Chaves County, NM","35006":"Cibola County, NM","35007":"Colfax County, NM","35009":"Curry County, NM","35011":"DeBaca County, NM","35013":"Dona Ana County, NM","35015":"Eddy County, NM","35017":"Grant County, NM","35019":"Guadalupe County, NM","35021":"Harding County, NM","35023":"Hidalgo County, NM","35025":"Lea County, NM","35027":"Lincoln County, NM","35028":"Los Alamos County, NM","35029":"Luna County, NM","35031":"McKinley County, NM","35033":"Mora County, NM","35035":"Otero County, NM","35037":"Quay County, NM","35039":"Rio Arriba County, NM","35041":"Roosevelt County, NM","35043":"Sandoval County, NM","35045":"San Juan County, NM","35047":"San Miguel County, NM","35049":"Santa Fe County, NM","35051":"Sierra County, NM","35053":"Socorro County, NM","35055":"Taos County, NM","35057":"Torrance County, NM","35059":"Union County, NM","35061":"Valencia County, NM","36001":"Albany County, NY","36003":"Allegany County, NY","36005":"Bronx County, NY","36007":"Broome County, NY","36009":"Cattaraugus County, NY","36011":"Cayuga County, NY","36013":"Chautauqua County, NY","36015":"Chemung County, NY","36017":"Chenango County, NY","36019":"Clinton County, NY","36021":"Columbia County, NY","36023":"Cortland County, NY","36025":"Delaware County, NY","36027":"Dutchess County, NY","36029":"Erie County, NY","36031":"Essex County, NY","36033":"Franklin County, NY","36035":"Fulton County, NY","36037":"Genesee County, NY","36039":"Greene County, NY","36041":"Hamilton County, NY","36043":"Herkimer County, NY","36045":"Jefferson County, NY","36047":"Kings County, NY","36049":"Lewis County, NY","36051":"Livingston County, NY","36053":"Madison County, NY","36055":"Monroe County, NY","36057":"Montgomery County, NY","36059":"Nassau County, NY","36061":"New York County, NY","36063":"Niagara County, NY","36065":"Oneida County, NY","36067":"Onondaga County, NY","36069":"Ontario County, NY","36071":"Orange County, NY","36073":"Orleans County, NY","36075":"Oswego County, NY","36077":"Otsego County, NY","36079":"Putnam County, NY","36081":"Queens County, NY","36083":"Rensselaer County, NY","36085":"Richmond County, NY","36087":"Rockland County, NY","36089":"St. Lawrence County, NY","36091":"Saratoga County, NY","36093":"Schenectady County, NY","36095":"Schoharie County, NY","36097":"Schuyler County, NY","36099":"Seneca County, NY","36101":"Steuben County, NY","36103":"Suffolk County, NY","36105":"Sullivan County, NY","36107":"Tioga County, NY","36109":"Tompkins County, NY","36111":"Ulster County, NY","36113":"Warren County, NY","36115":"Washington County, NY","36117":"Wayne County, NY","36119":"Westchester County, NY","36121":"Wyoming County, NY","36123":"Yates County, NY","37001":"Alamance County, NC","37003":"Alexander County, NC","37005":"Alleghany County, NC","37007":"Anson County, NC","37009":"Ashe County, NC","37011":"Avery County, NC","37013":"Beaufort County, NC","37015":"Bertie County, NC","37017":"Bladen County, NC","37019":"Brunswick County, NC","37021":"Buncombe County, NC","37023":"Burke County, NC","37025":"Cabarrus County, NC","37027":"Caldwell County, NC","37029":"Camden County, NC","37031":"Carteret County, NC","37033":"Caswell County, NC","37035":"Catawba County, NC","37037":"Chatham County, NC","37039":"Cherokee County, NC","37041":"Chowan County, NC","37043":"Clay County, NC","37045":"Cleveland County, NC","37047":"Columbus County, NC","37049":"Craven County, NC","37051":"Cumberland County, NC","37053":"Currituck County, NC","37055":"Dare County, NC","37057":"Davidson County, NC","37059":"Davie County, NC","37061":"Duplin County, NC","37063":"Durham County, NC","37065":"Edgecombe County, NC","37067":"Forsyth County, NC","37069":"Franklin County, NC","37071":"Gaston County, NC","37073":"Gates County, NC","37075":"Graham County, NC","37077":"Granville County, NC","37079":"Greene County, NC","37081":"Guilford County, NC","37083":"Halifax County, NC","37085":"Harnett County, NC","37087":"Haywood County, NC","37089":"Henderson County, NC","37091":"Hertford County, NC","37093":"Hoke County, NC","37095":"Hyde County, NC","37097":"Iredell County, NC","37099":"Jackson County, NC","37101":"Johnston County, NC","37103":"Jones County, NC","37105":"Lee County, NC","37107":"Lenoir County, NC","37109":"Lincoln County, NC","37111":"McDowell County, NC","37113":"Macon County, NC","37115":"Madison County, NC","37117":"Martin County, NC","37119":"Mecklenburg County, NC","37121":"Mitchell County, NC","37123":"Montgomery County, NC","37125":"Moore County, NC","37127":"Nash County, NC","37129":"New Hanover County, NC","37131":"Northampton County, NC","37133":"Onslow County, NC","37135":"Orange County, NC","37137":"Pamlico County, NC","37139":"Pasquotank County, NC","37141":"Pender County, NC","37143":"Perquimans County, NC","37145":"Person County, NC","37147":"Pitt County, NC","37149":"Polk County, NC","37151":"Randolph County, NC","37153":"Richmond County, NC","37155":"Robeson County, NC","37157":"Rockingham County, NC","37159":"Rowan County, NC","37161":"Rutherford County, NC","37163":"Sampson County, NC","37165":"Scotland County, NC","37167":"Stanly County, NC","37169":"Stokes County, NC","37171":"Surry County, NC","37173":"Swain County, NC","37175":"Transylvania County, NC","37177":"Tyrrell County, NC","37179":"Union County, NC","37181":"Vance County, NC","37183":"Wake County, NC","37185":"Warren County, NC","37187":"Washington County, NC","37189":"Watauga County, NC","37191":"Wayne County, NC","37193":"Wilkes County, NC","37195":"Wilson County, NC","37197":"Yadkin County, NC","37199":"Yancey County, NC","38001":"Adams County, ND","38003":"Barnes County, ND","38005":"Benson County, ND","38007":"Billings County, ND","38009":"Bottineau County, ND","38011":"Bowman County, ND","38013":"Burke County, ND","38015":"Burleigh County, ND","38017":"Cass County, ND","38019":"Cavalier County, ND","38021":"Dickey County, ND","38023":"Divide County, ND","38025":"Dunn County, ND","38027":"Eddy County, ND","38029":"Emmons County, ND","38031":"Foster County, ND","38033":"Golden Valley County, ND","38035":"Grand Forks County, ND","38037":"Grant County, ND","38039":"Griggs County, ND","38041":"Hettinger County, ND","38043":"Kidder County, ND","38045":"LaMoure County, ND","38047":"Logan County, ND","38049":"McHenry County, ND","38051":"McIntosh County, ND","38053":"McKenzie County, ND","38055":"McLean County, ND","38057":"Mercer County, ND","38059":"Morton County, ND","38061":"Mountrail County, ND","38063":"Nelson County, ND","38065":"Oliver County, ND","38067":"Pembina County, ND","38069":"Pierce County, ND","38071":"Ramsey County, ND","38073":"Ransom County, ND","38075":"Renville County, ND","38077":"Richland County, ND","38079":"Rolette County, ND","38081":"Sargent County, ND","38083":"Sheridan County, ND","38085":"Sioux County, ND","38087":"Slope County, ND","38089":"Stark County, ND","38091":"Steele County, ND","38093":"Stutsman County, ND","38095":"Towner County, ND","38097":"Traill County, ND","38099":"Walsh County, ND","38101":"Ward County, ND","38103":"Wells County, ND","38105":"Williams County, ND","39001":"Adams County, OH","39003":"Allen County, OH","39005":"Ashland County, OH","39007":"Ashtabula County, OH","39009":"Athens County, OH","39011":"Auglaize County, OH","39013":"Belmont County, OH","39015":"Brown County, OH","39017":"Butler County, OH","39019":"Carroll County, OH","39021":"Champaign County, OH","39023":"Clark County, OH","39025":"Clermont County, OH","39027":"Clinton County, OH","39029":"Columbiana County, OH","39031":"Coshocton County, OH","39033":"Crawford County, OH","39035":"Cuyahoga County, OH","39037":"Darke County, OH","39039":"Defiance County, OH","39041":"Delaware County, OH","39043":"Erie County, OH","39045":"Fairfield County, OH","39047":"Fayette County, OH","39049":"Franklin County, OH","39051":"Fulton County, OH","39053":"Gallia County, OH","39055":"Geauga County, OH","39057":"Greene County, OH","39059":"Guernsey County, OH","39061":"Hamilton County, OH","39063":"Hancock County, OH","39065":"Hardin County, OH","39067":"Harrison County, OH","39069":"Henry County, OH","39071":"Highland County, OH","39073":"Hocking County, OH","39075":"Holmes County, OH","39077":"Huron County, OH","39079":"Jackson County, OH","39081":"Jefferson County, OH","39083":"Knox County, OH","39085":"Lake County, OH","39087":"Lawrence County, OH","39089":"Licking County, OH","39091":"Logan County, OH","39093":"Lorain County, OH","39095":"Lucas County, OH","39097":"Madison County, OH","39099":"Mahoning County, OH","39101":"Marion County, OH","39103":"Medina County, OH","39105":"Meigs County, OH","39107":"Mercer County, OH","39109":"Miami County, OH","39111":"Monroe County, OH","39113":"Montgomery County, OH","39115":"Morgan County, OH","39117":"Morrow County, OH","39119":"Muskingum County, OH","39121":"Noble County, OH","39123":"Ottawa County, OH","39125":"Paulding County, OH","39127":"Perry County, OH","39129":"Pickaway County, OH","39131":"Pike County, OH","39133":"Portage County, OH","39135":"Preble County, OH","39137":"Putnam County, OH","39139":"Richland County, OH","39141":"Ross County, OH","39143":"Sandusky County, OH","39145":"Scioto County, OH","39147":"Seneca County, OH","39149":"Shelby County, OH","39151":"Stark County, OH","39153":"Summit County, OH","39155":"Trumbull County, OH","39157":"Tuscarawas County, OH","39159":"Union County, OH","39161":"Van Wert County, OH","39163":"Vinton County, OH","39165":"Warren County, OH","39167":"Washington County, OH","39169":"Wayne County, OH","39171":"Williams County, OH","39173":"Wood County, OH","39175":"Wyandot County, OH","40001":"Adair County, OK","40003":"Alfalfa County, OK","40005":"Atoka County, OK","40007":"Beaver County, OK","40009":"Beckham County, OK","40011":"Blaine County, OK","40013":"Bryan County, OK","40015":"Caddo County, OK","40017":"Canadian County, OK","40019":"Carter County, OK","40021":"Cherokee County, OK","40023":"Choctaw County, OK","40025":"Cimarron County, OK","40027":"Cleveland County, OK","40029":"Coal County, OK","40031":"Comanche County, OK","40033":"Cotton County, OK","40035":"Craig County, OK","40037":"Creek County, OK","40039":"Custer County, OK","40041":"Delaware County, OK","40043":"Dewey County, OK","40045":"Ellis County, OK","40047":"Garfield County, OK","40049":"Garvin County, OK","40051":"Grady County, OK","40053":"Grant County, OK","40055":"Greer County, OK","40057":"Harmon County, OK","40059":"Harper County, OK","40061":"Haskell County, OK","40063":"Hughes County, OK","40065":"Jackson County, OK","40067":"Jefferson County, OK","40069":"Johnston County, OK","40071":"Kay County, OK","40073":"Kingfisher County, OK","40075":"Kiowa County, OK","40077":"Latimer County, OK","40079":"Le Flore County, OK","40081":"Lincoln County, OK","40083":"Logan County, OK","40085":"Love County, OK","40087":"McClain County, OK","40089":"McCurtain County, OK","40091":"McIntosh County, OK","40093":"Major County, OK","40095":"Marshall County, OK","40097":"Mayes County, OK","40099":"Murray County, OK","40101":"Muskogee County, OK","40103":"Noble County, OK","40105":"Nowata County, OK","40107":"Okfuskee County, OK","40109":"Oklahoma County, OK","40111":"Okmulgee County, OK","40113":"Osage County, OK","40115":"Ottawa County, OK","40117":"Pawnee County, OK","40119":"Payne County, OK","40121":"Pittsburg County, OK","40123":"Pontotoc County, OK","40125":"Pottawatomie County, OK","40127":"Pushmataha County, OK","40129":"Roger Mills County, OK","40131":"Rogers County, OK","40133":"Seminole County, OK","40135":"Sequoyah County, OK","40137":"Stephens County, OK","40139":"Texas County, OK","40141":"Tillman County, OK","40143":"Tulsa County, OK","40145":"Wagoner County, OK","40147":"Washington County, OK","40149":"Washita County, OK","40151":"Woods County, OK","40153":"Woodward County, OK","41001":"Baker County, OR","41003":"Benton County, OR","41005":"Clackamas County, OR","41007":"Clatsop County, OR","41009":"Columbia County, OR","41011":"Coos County, OR","41013":"Crook County, OR","41015":"Curry County, OR","41017":"Deschutes County, OR","41019":"Douglas County, OR","41021":"Gilliam County, OR","41023":"Grant County, OR","41025":"Harney County, OR","41027":"Hood River County, OR","41029":"Jackson County, OR","41031":"Jefferson County, OR","41033":"Josephine County, OR","41035":"Klamath County, OR","41037":"Lake County, OR","41039":"Lane County, OR","41041":"Lincoln County, OR","41043":"Linn County, OR","41045":"Malheur County, OR","41047":"Marion County, OR","41049":"Morrow County, OR","41051":"Multnomah County, OR","41053":"Polk County, OR","41055":"Sherman County, OR","41057":"Tillamook County, OR","41059":"Umatilla County, OR","41061":"Union County, OR","41063":"Wallowa County, OR","41065":"Wasco County, OR","41067":"Washington County, OR","41069":"Wheeler County, OR","41071":"Yamhill County, OR","42001":"Adams County, PA","42003":"Allegheny County, PA","42005":"Armstrong County, PA","42007":"Beaver County, PA","42009":"Bedford County, PA","42011":"Berks County, PA","42013":"Blair County, PA","42015":"Bradford County, PA","42017":"Bucks County, PA","42019":"Butler County, PA","42021":"Cambria County, PA","42023":"Cameron County, PA","42025":"Carbon County, PA","42027":"Centre County, PA","42029":"Chester County, PA","42031":"Clarion County, PA","42033":"Clearfield County, PA","42035":"Clinton County, PA","42037":"Columbia County, PA","42039":"Crawford County, PA","42041":"Cumberland County, PA","42043":"Dauphin County, PA","42045":"Delaware County, PA","42047":"Elk County, PA","42049":"Erie County, PA","42051":"Fayette County, PA","42053":"Forest County, PA","42055":"Franklin County, PA","42057":"Fulton County, PA","42059":"Greene County, PA","42061":"Huntingdon County, PA","42063":"Indiana County, PA","42065":"Jefferson County, PA","42067":"Juniata County, PA","42069":"Lackawanna County, PA","42071":"Lancaster County, PA","42073":"Lawrence County, PA","42075":"Lebanon County, PA","42077":"Lehigh County, PA","42079":"Luzerne County, PA","42081":"Lycoming County, PA","42083":"McKean County, PA","42085":"Mercer County, PA","42087":"Mifflin County, PA","42089":"Monroe County, PA","42091":"Montgomery County, PA","42093":"Montour County, PA","42095":"Northampton County, PA","42097":"Northumberland County, PA","42099":"Perry County, PA","42101":"Philadelphia County, PA","42103":"Pike County, PA","42105":"Potter County, PA","42107":"Schuylkill County, PA","42109":"Snyder County, PA","42111":"Somerset County, PA","42113":"Sullivan County, PA","42115":"Susquehanna County, PA","42117":"Tioga County, PA","42119":"Union County, PA","42121":"Venango County, PA","42123":"Warren County, PA","42125":"Washington County, PA","42127":"Wayne County, PA","42129":"Westmoreland County, PA","42131":"Wyoming County, PA","42133":"York County, PA","44001":"Bristol County, RI","44003":"Kent County, RI","44005":"Newport County, RI","44007":"Providence County, RI","44009":"Washington County, RI","45001":"Abbeville County, SC","45003":"Aiken County, SC","45005":"Allendale County, SC","45007":"Anderson County, SC","45009":"Bamberg County, SC","45011":"Barnwell County, SC","45013":"Beaufort County, SC","45015":"Berkeley County, SC","45017":"Calhoun County, SC","45019":"Charleston County, SC","45021":"Cherokee County, SC","45023":"Chester County, SC","45025":"Chesterfield County, SC","45027":"Clarendon County, SC","45029":"Colleton County, SC","45031":"Darlington County, SC","45033":"Dillon County, SC","45035":"Dorchester County, SC","45037":"Edgefield County, SC","45039":"Fairfield County, SC","45041":"Florence County, SC","45043":"Georgetown County, SC","45045":"Greenville County, SC","45047":"Greenwood County, SC","45049":"Hampton County, SC","45051":"Horry County, SC","45053":"Jasper County, SC","45055":"Kershaw County, SC","45057":"Lancaster County, SC","45059":"Laurens County, SC","45061":"Lee County, SC","45063":"Lexington County, SC","45065":"McCormick County, SC","45067":"Marion County, SC","45069":"Marlboro County, SC","45071":"Newberry County, SC","45073":"Oconee County, SC","45075":"Orangeburg County, SC","45077":"Pickens County, SC","45079":"Richland County, SC","45081":"Saluda County, SC","45083":"Spartanburg County, SC","45085":"Sumter County, SC","45087":"Union County, SC","45089":"Williamsburg County, SC","45091":"York County, SC","46003":"Aurora County, SD","46005":"Beadle County, SD","46007":"Bennett County, SD","46009":"Bon Homme County, SD","46011":"Brookings County, SD","46013":"Brown County, SD","46015":"Brule County, SD","46017":"Buffalo County, SD","46019":"Butte County, SD","46021":"Campbell County, SD","46023":"Charles Mix County, SD","46025":"Clark County, SD","46027":"Clay County, SD","46029":"Codington County, SD","46031":"Corson County, SD","46033":"Custer County, SD","46035":"Davison County, SD","46037":"Day County, SD","46039":"Deuel County, SD","46041":"Dewey County, SD","46043":"Douglas County, SD","46045":"Edmunds County, SD","46047":"Fall River County, SD","46049":"Faulk County, SD","46051":"Grant County, SD","46053":"Gregory County, SD","46055":"Haakon County, SD","46057":"Hamlin County, SD","46059":"Hand County, SD","46061":"Hanson County, SD","46063":"Harding County, SD","46065":"Hughes County, SD","46067":"Hutchinson County, SD","46069":"Hyde County, SD","46071":"Jackson County, SD","46073":"Jerauld County, SD","46075":"Jones County, SD","46077":"Kingsbury County, SD","46079":"Lake County, SD","46081":"Lawrence County, SD","46083":"Lincoln County, SD","46085":"Lyman County, SD","46087":"McCook County, SD","46089":"McPherson County, SD","46091":"Marshall County, SD","46093":"Meade County, SD","46095":"Mellette County, SD","46097":"Miner County, SD","46099":"Minnehaha County, SD","46101":"Moody County, SD","46103":"Pennington County, SD","46105":"Perkins County, SD","46107":"Potter County, SD","46109":"Roberts County, SD","46111":"Sanborn County, SD","46113":"Shannon County, SD","46115":"Spink County, SD","46117":"Stanley County, SD","46119":"Sully County, SD","46121":"Todd County, SD","46123":"Tripp County, SD","46125":"Turner County, SD","46127":"Union County, SD","46129":"Walworth County, SD","46135":"Yankton County, SD","46137":"Ziebach County, SD","47001":"Anderson County, TN","47003":"Bedford County, TN","47005":"Benton County, TN","47007":"Bledsoe County, TN","47009":"Blount County, TN","47011":"Bradley County, TN","47013":"Campbell County, TN","47015":"Cannon County, TN","47017":"Carroll County, TN","47019":"Carter County, TN","47021":"Cheatham County, TN","47023":"Chester County, TN","47025":"Claiborne County, TN","47027":"Clay County, TN","47029":"Cocke County, TN","47031":"Coffee County, TN","47033":"Crockett County, TN","47035":"Cumberland County, TN","47037":"Davidson County, TN","47039":"Decatur County, TN","47041":"DeKalb County, TN","47043":"Dickson County, TN","47045":"Dyer County, TN","47047":"Fayette County, TN","47049":"Fentress County, TN","47051":"Franklin County, TN","47053":"Gibson County, TN","47055":"Giles County, TN","47057":"Grainger County, TN","47059":"Greene County, TN","47061":"Grundy County, TN","47063":"Hamblen County, TN","47065":"Hamilton County, TN","47067":"Hancock County, TN","47069":"Hardeman County, TN","47071":"Hardin County, TN","47073":"Hawkins County, TN","47075":"Haywood County, TN","47077":"Henderson County, TN","47079":"Henry County, TN","47081":"Hickman County, TN","47083":"Houston County, TN","47085":"Humphreys County, TN","47087":"Jackson County, TN","47089":"Jefferson County, TN","47091":"Johnson County, TN","47093":"Knox County, TN","47095":"Lake County, TN","47097":"Lauderdale County, TN","47099":"Lawrence County, TN","47101":"Lewis County, TN","47103":"Lincoln County, TN","47105":"Loudon County, TN","47107":"McMinn County, TN","47109":"McNairy County, TN","47111":"Macon County, TN","47113":"Madison County, TN","47115":"Marion County, TN","47117":"Marshall County, TN","47119":"Maury County, TN","47121":"Meigs County, TN","47123":"Monroe County, TN","47125":"Montgomery County, TN","47127":"Moore County, TN","47129":"Morgan County, TN","47131":"Obion County, TN","47133":"Overton County, TN","47135":"Perry County, TN","47137":"Pickett County, TN","47139":"Polk County, TN","47141":"Putnam County, TN","47143":"Rhea County, TN","47145":"Roane County, TN","47147":"Robertson County, TN","47149":"Rutherford County, TN","47151":"Scott County, TN","47153":"Sequatchie County, TN","47155":"Sevier County, TN","47157":"Shelby County, TN","47159":"Smith County, TN","47161":"Stewart County, TN","47163":"Sullivan County, TN","47165":"Sumner County, TN","47167":"Tipton County, TN","47169":"Trousdale County, TN","47171":"Unicoi County, TN","47173":"Union County, TN","47175":"Van Buren County, TN","47177":"Warren County, TN","47179":"Washington County, TN","47181":"Wayne County, TN","47183":"Weakley County, TN","47185":"White County, TN","47187":"Williamson County, TN","47189":"Wilson County, TN","48001":"Anderson County, TX","48003":"Andrews County, TX","48005":"Angelina County, TX","48007":"Aransas County, TX","48009":"Archer County, TX","48011":"Armstrong County, TX","48013":"Atascosa County, TX","48015":"Austin County, TX","48017":"Bailey County, TX","48019":"Bandera County, TX","48021":"Bastrop County, TX","48023":"Baylor County, TX","48025":"Bee County, TX","48027":"Bell County, TX","48029":"Bexar County, TX","48031":"Blanco County, TX","48033":"Borden County, TX","48035":"Bosque County, TX","48037":"Bowie County, TX","48039":"Brazoria County, TX","48041":"Brazos County, TX","48043":"Brewster County, TX","48045":"Briscoe County, TX","48047":"Brooks County, TX","48049":"Brown County, TX","48051":"Burleson County, TX","48053":"Burnet County, TX","48055":"Caldwell County, TX","48057":"Calhoun County, TX","48059":"Callahan County, TX","48061":"Cameron County, TX","48063":"Camp County, TX","48065":"Carson County, TX","48067":"Cass County, TX","48069":"Castro County, TX","48071":"Chambers County, TX","48073":"Cherokee County, TX","48075":"Childress County, TX","48077":"Clay County, TX","48079":"Cochran County, TX","48081":"Coke County, TX","48083":"Coleman County, TX","48085":"Collin County, TX","48087":"Collingsworth County, TX","48089":"Colorado County, TX","48091":"Comal County, TX","48093":"Comanche County, TX","48095":"Concho County, TX","48097":"Cooke County, TX","48099":"Coryell County, TX","48101":"Cottle County, TX","48103":"Crane County, TX","48105":"Crockett County, TX","48107":"Crosby County, TX","48109":"Culberson County, TX","48111":"Dallam County, TX","48113":"Dallas County, TX","48115":"Dawson County, TX","48117":"Deaf Smith County, TX","48119":"Delta County, TX","48121":"Denton County, TX","48123":"DeWitt County, TX","48125":"Dickens County, TX","48127":"Dimmit County, TX","48129":"Donley County, TX","48131":"Duval County, TX","48133":"Eastland County, TX","48135":"Ector County, TX","48137":"Edwards County, TX","48139":"Ellis County, TX","48141":"El Paso County, TX","48143":"Erath County, TX","48145":"Falls County, TX","48147":"Fannin County, TX","48149":"Fayette County, TX","48151":"Fisher County, TX","48153":"Floyd County, TX","48155":"Foard County, TX","48157":"Fort Bend County, TX","48159":"Franklin County, TX","48161":"Freestone County, TX","48163":"Frio County, TX","48165":"Gaines County, TX","48167":"Galveston County, TX","48169":"Garza County, TX","48171":"Gillespie County, TX","48173":"Glasscock County, TX","48175":"Goliad County, TX","48177":"Gonzales County, TX","48179":"Gray County, TX","48181":"Grayson County, TX","48183":"Gregg County, TX","48185":"Grimes County, TX","48187":"Guadalupe County, TX","48189":"Hale County, TX","48191":"Hall County, TX","48193":"Hamilton County, TX","48195":"Hansford County, TX","48197":"Hardeman County, TX","48199":"Hardin County, TX","48201":"Harris County, TX","48203":"Harrison County, TX","48205":"Hartley County, TX","48207":"Haskell County, TX","48209":"Hays County, TX","48211":"Hemphill County, TX","48213":"Henderson County, TX","48215":"Hidalgo County, TX","48217":"Hill County, TX","48219":"Hockley County, TX","48221":"Hood County, TX","48223":"Hopkins County, TX","48225":"Houston County, TX","48227":"Howard County, TX","48229":"Hudspeth County, TX","48231":"Hunt County, TX","48233":"Hutchinson County, TX","48235":"Irion County, TX","48237":"Jack County, TX","48239":"Jackson County, TX","48241":"Jasper County, TX","48243":"Jeff Davis County, TX","48245":"Jefferson County, TX","48247":"Jim Hogg County, TX","48249":"Jim Wells County, TX","48251":"Johnson County, TX","48253":"Jones County, TX","48255":"Karnes County, TX","48257":"Kaufman County, TX","48259":"Kendall County, TX","48261":"Kenedy County, TX","48263":"Kent County, TX","48265":"Kerr County, TX","48267":"Kimble County, TX","48269":"King County, TX","48271":"Kinney County, TX","48273":"Kleberg County, TX","48275":"Knox County, TX","48277":"Lamar County, TX","48279":"Lamb County, TX","48281":"Lampasas County, TX","48283":"La Salle County, TX","48285":"Lavaca County, TX","48287":"Lee County, TX","48289":"Leon County, TX","48291":"Liberty County, TX","48293":"Limestone County, TX","48295":"Lipscomb County, TX","48297":"Live Oak County, TX","48299":"Llano County, TX","48301":"Loving County, TX","48303":"Lubbock County, TX","48305":"Lynn County, TX","48307":"McCulloch County, TX","48309":"McLennan County, TX","48311":"McMullen County, TX","48313":"Madison County, TX","48315":"Marion County, TX","48317":"Martin County, TX","48319":"Mason County, TX","48321":"Matagorda County, TX","48323":"Maverick County, TX","48325":"Medina County, TX","48327":"Menard County, TX","48329":"Midland County, TX","48331":"Milam County, TX","48333":"Mills County, TX","48335":"Mitchell County, TX","48337":"Montague County, TX","48339":"Montgomery County, TX","48341":"Moore County, TX","48343":"Morris County, TX","48345":"Motley County, TX","48347":"Nacogdoches County, TX","48349":"Navarro County, TX","48351":"Newton County, TX","48353":"Nolan County, TX","48355":"Nueces County, TX","48357":"Ochiltree County, TX","48359":"Oldham County, TX","48361":"Orange County, TX","48363":"Palo Pinto County, TX","48365":"Panola County, TX","48367":"Parker County, TX","48369":"Parmer County, TX","48371":"Pecos County, TX","48373":"Polk County, TX","48375":"Potter County, TX","48377":"Presidio County, TX","48379":"Rains County, TX","48381":"Randall County, TX","48383":"Reagan County, TX","48385":"Real County, TX","48387":"Red River County, TX","48389":"Reeves County, TX","48391":"Refugio County, TX","48393":"Roberts County, TX","48395":"Robertson County, TX","48397":"Rockwall County, TX","48399":"Runnels County, TX","48401":"Rusk County, TX","48403":"Sabine County, TX","48405":"San Augustine County, TX","48407":"San Jacinto County, TX","48409":"San Patricio County, TX","48411":"San Saba County, TX","48413":"Schleicher County, TX","48415":"Scurry County, TX","48417":"Shackelford County, TX","48419":"Shelby County, TX","48421":"Sherman County, TX","48423":"Smith County, TX","48425":"Somervell County, TX","48427":"Starr County, TX","48429":"Stephens County, TX","48431":"Sterling County, TX","48433":"Stonewall County, TX","48435":"Sutton County, TX","48437":"Swisher County, TX","48439":"Tarrant County, TX","48441":"Taylor County, TX","48443":"Terrell County, TX","48445":"Terry County, TX","48447":"Throckmorton County, TX","48449":"Titus County, TX","48451":"Tom Green County, TX","48453":"Travis County, TX","48455":"Trinity County, TX","48457":"Tyler County, TX","48459":"Upshur County, TX","48461":"Upton County, TX","48463":"Uvalde County, TX","48465":"Val Verde County, TX","48467":"Van Zandt County, TX","48469":"Victoria County, TX","48471":"Walker County, TX","48473":"Waller County, TX","48475":"Ward County, TX","48477":"Washington County, TX","48479":"Webb County, TX","48481":"Wharton County, TX","48483":"Wheeler County, TX","48485":"Wichita County, TX","48487":"Wilbarger County, TX","48489":"Willacy County, TX","48491":"Williamson County, TX","48493":"Wilson County, TX","48495":"Winkler County, TX","48497":"Wise County, TX","48499":"Wood County, TX","48501":"Yoakum County, TX","48503":"Young County, TX","48505":"Zapata County, TX","48507":"Zavala County, TX","49001":"Beaver County, UT","49003":"Box Elder County, UT","49005":"Cache County, UT","49007":"Carbon County, UT","49009":"Daggett County, UT","49011":"Davis County, UT","49013":"Duchesne County, UT","49015":"Emery County, UT","49017":"Garfield County, UT","49019":"Grand County, UT","49021":"Iron County, UT","49023":"Juab County, UT","49025":"Kane County, UT","49027":"Millard County, UT","49029":"Morgan County, UT","49031":"Piute County, UT","49033":"Rich County, UT","49035":"Salt Lake County, UT","49037":"San Juan County, UT","49039":"Sanpete County, UT","49041":"Sevier County, UT","49043":"Summit County, UT","49045":"Tooele County, UT","49047":"Uintah County, UT","49049":"Utah County, UT","49051":"Wasatch County, UT","49053":"Washington County, UT","49055":"Wayne County, UT","49057":"Weber County, UT","50001":"Addison County, VT","50003":"Bennington County, VT","50005":"Caledonia County, VT","50007":"Chittenden County, VT","50009":"Essex County, VT","50011":"Franklin County, VT","50013":"Grand Isle County, VT","50015":"Lamoille County, VT","50017":"Orange County, VT","50019":"Orleans County, VT","50021":"Rutland County, VT","50023":"Washington County, VT","50025":"Windham County, VT","50027":"Windsor County, VT","51001":"Accomack County, VA","51003":"Albemarle County, VA","51005":"Alleghany County, VA","51007":"Amelia County, VA","51009":"Amherst County, VA","51011":"Appomattox County, VA","51013":"Arlington County, VA","51015":"Augusta County, VA","51017":"Bath County, VA","51019":"Bedford County, VA","51021":"Bland County, VA","51023":"Botetourt County, VA","51025":"Brunswick County, VA","51027":"Buchanan County, VA","51029":"Buckingham County, VA","51031":"Campbell County, VA","51033":"Caroline County, VA","51035":"Carroll County, VA","51036":"Charles City County, VA","51037":"Charlotte County, VA","51041":"Chesterfield County, VA","51043":"Clarke County, VA","51045":"Craig County, VA","51047":"Culpeper County, VA","51049":"Cumberland County, VA","51051":"Dickenson County, VA","51053":"Dinwiddie County, VA","51057":"Essex County, VA","51059":"Fairfax county County, VA","51061":"Fauquier County, VA","51063":"Floyd County, VA","51065":"Fluvanna County, VA","51067":"Franklin County, VA","51069":"Frederick County, VA","51071":"Giles County, VA","51073":"Gloucester County, VA","51075":"Goochland County, VA","51077":"Grayson County, VA","51079":"Greene County, VA","51081":"Greensville County, VA","51083":"Halifax County, VA","51085":"Hanover County, VA","51087":"Henrico County, VA","51089":"Henry County, VA","51091":"Highland County, VA","51093":"Isle of Wight County, VA","51095":"James City County, VA","51097":"King and Queen County, VA","51099":"King George County, VA","51101":"King William County, VA","51103":"Lancaster County, VA","51105":"Lee County, VA","51107":"Loudoun County, VA","51109":"Louisa County, VA","51111":"Lunenburg County, VA","51113":"Madison County, VA","51115":"Mathews County, VA","51117":"Mecklenburg County, VA","51119":"Middlesex County, VA","51121":"Montgomery County, VA","51125":"Nelson County, VA","51127":"New Kent County, VA","51131":"Northampton County, VA","51133":"Northumberland County, VA","51135":"Nottoway County, VA","51137":"Orange County, VA","51139":"Page County, VA","51141":"Patrick County, VA","51143":"Pittsylvania County, VA","51145":"Powhatan County, VA","51147":"Prince Edward County, VA","51149":"Prince George County, VA","51153":"Prince William County, VA","51155":"Pulaski County, VA","51157":"Rappahannock County, VA","51159":"Richmond County, VA","51161":"Roanoke County, VA","51163":"Rockbridge County, VA","51165":"Rockingham County, VA","51167":"Russell County, VA","51169":"Scott County, VA","51171":"Shenandoah County, VA","51173":"Smyth County, VA","51175":"Southampton County, VA","51177":"Spotsylvania County, VA","51179":"Stafford County, VA","51181":"Surry County, VA","51183":"Sussex County, VA","51185":"Tazewell County, VA","51187":"Warren County, VA","51191":"Washington County, VA","51193":"Westmoreland County, VA","51195":"Wise County, VA","51197":"Wythe County, VA","51199":"York County, VA","51510":"City of Alexandria, VA","51515":"City of Bedford, VA","51520":"City of Bristol, VA","51530":"City of Buena Vista, VA","51540":"City of Charlottesville, VA","51550":"City of Chesapeake, VA","51560":"City of Clifton Forge, VA","51570":"City of Colonial Heights, VA","51580":"City of Covington, VA","51590":"City of Danville, VA","51595":"City of Emporia, VA","51600":"City of Fairfax, VA","51610":"City of Falls Church, VA","51620":"City of Franklin, VA","51630":"City of Fredericksburg, VA","51640":"City of Galax, VA","51650":"City of Hampton, VA","51660":"City of Harrisonburg, VA","51670":"City of Hopewell, VA","51678":"City of Lexington, VA","51680":"City of Lynchburg, VA","51683":"City of Manassas, VA","51685":"City of Manassas Park, VA","51690":"City of Martinsville, VA","51700":"City of Newport News, VA","51710":"City of Norfolk, VA","51720":"City of Norton, VA","51730":"City of Petersburg, VA","51735":"City of Poquoson, VA","51740":"City of Portsmouth, VA","51750":"City of Radford, VA","51760":"City of Richmond, VA","51770":"City of Roanoke, VA","51775":"City of Salem, VA","51790":"City of Staunton, VA","51800":"City of Suffolk, VA","51810":"City of Virginia Beach, VA","51820":"City of Waynesboro, VA","51830":"City of Williamsburg, VA","51840":"City of Winchester, VA","53001":"Adams County, WA","53003":"Asotin County, WA","53005":"Benton County, WA","53007":"Chelan County, WA","53009":"Clallam County, WA","53011":"Clark County, WA","53013":"Columbia County, WA","53015":"Cowlitz County, WA","53017":"Douglas County, WA","53019":"Ferry County, WA","53021":"Franklin County, WA","53023":"Garfield County, WA","53025":"Grant County, WA","53027":"Grays Harbor County, WA","53029":"Island County, WA","53031":"Jefferson County, WA","53033":"King County, WA","53035":"Kitsap County, WA","53037":"Kittitas County, WA","53039":"Klickitat County, WA","53041":"Lewis County, WA","53043":"Lincoln County, WA","53045":"Mason County, WA","53047":"Okanogan County, WA","53049":"Pacific County, WA","53051":"Pend Oreille County, WA","53053":"Pierce County, WA","53055":"San Juan County, WA","53057":"Skagit County, WA","53059":"Skamania County, WA","53061":"Snohomish County, WA","53063":"Spokane County, WA","53065":"Stevens County, WA","53067":"Thurston County, WA","53069":"Wahkiakum County, WA","53071":"Walla Walla County, WA","53073":"Whatcom County, WA","53075":"Whitman County, WA","53077":"Yakima County, WA","54001":"Barbour County, WV","54003":"Berkeley County, WV","54005":"Boone County, WV","54007":"Braxton County, WV","54009":"Brooke County, WV","54011":"Cabell County, WV","54013":"Calhoun County, WV","54015":"Clay County, WV","54017":"Doddridge County, WV","54019":"Fayette County, WV","54021":"Gilmer County, WV","54023":"Grant County, WV","54025":"Greenbrier County, WV","54027":"Hampshire County, WV","54029":"Hancock County, WV","54031":"Hardy County, WV","54033":"Harrison County, WV","54035":"Jackson County, WV","54037":"Jefferson County, WV","54039":"Kanawha County, WV","54041":"Lewis County, WV","54043":"Lincoln County, WV","54045":"Logan County, WV","54047":"McDowell County, WV","54049":"Marion County, WV","54051":"Marshall County, WV","54053":"Mason County, WV","54055":"Mercer County, WV","54057":"Mineral County, WV","54059":"Mingo County, WV","54061":"Monongalia County, WV","54063":"Monroe County, WV","54065":"Morgan County, WV","54067":"Nicholas County, WV","54069":"Ohio County, WV","54071":"Pendleton County, WV","54073":"Pleasants County, WV","54075":"Pocahontas County, WV","54077":"Preston County, WV","54079":"Putnam County, WV","54081":"Raleigh County, WV","54083":"Randolph County, WV","54085":"Ritchie County, WV","54087":"Roane County, WV","54089":"Summers County, WV","54091":"Taylor County, WV","54093":"Tucker County, WV","54095":"Tyler County, WV","54097":"Upshur County, WV","54099":"Wayne County, WV","54101":"Webster County, WV","54103":"Wetzel County, WV","54105":"Wirt County, WV","54107":"Wood County, WV","54109":"Wyoming County, WV","55001":"Adams County, WI","55003":"Ashland County, WI","55005":"Barron County, WI","55007":"Bayfield County, WI","55009":"Brown County, WI","55011":"Buffalo County, WI","55013":"Burnett County, WI","55015":"Calumet County, WI","55017":"Chippewa County, WI","55019":"Clark County, WI","55021":"Columbia County, WI","55023":"Crawford County, WI","55025":"Dane County, WI","55027":"Dodge County, WI","55029":"Door County, WI","55031":"Douglas County, WI","55033":"Dunn County, WI","55035":"Eau Claire County, WI","55037":"Florence County, WI","55039":"Fond du Lac County, WI","55041":"Forest County, WI","55043":"Grant County, WI","55045":"Green County, WI","55047":"Green Lake County, WI","55049":"Iowa County, WI","55051":"Iron County, WI","55053":"Jackson County, WI","55055":"Jefferson County, WI","55057":"Juneau County, WI","55059":"Kenosha County, WI","55061":"Kewaunee County, WI","55063":"La Crosse County, WI","55065":"Lafayette County, WI","55067":"Langlade County, WI","55069":"Lincoln County, WI","55071":"Manitowoc County, WI","55073":"Marathon County, WI","55075":"Marinette County, WI","55077":"Marquette County, WI","55078":"Menominee County, WI","55079":"Milwaukee County, WI","55081":"Monroe County, WI","55083":"Oconto County, WI","55085":"Oneida County, WI","55087":"Outagamie County, WI","55089":"Ozaukee County, WI","55091":"Pepin County, WI","55093":"Pierce County, WI","55095":"Polk County, WI","55097":"Portage County, WI","55099":"Price County, WI","55101":"Racine County, WI","55103":"Richland County, WI","55105":"Rock County, WI","55107":"Rusk County, WI","55109":"St. Croix County, WI","55111":"Sauk County, WI","55113":"Sawyer County, WI","55115":"Shawano County, WI","55117":"Sheboygan County, WI","55119":"Taylor County, WI","55121":"Trempealeau County, WI","55123":"Vernon County, WI","55125":"Vilas County, WI","55127":"Walworth County, WI","55129":"Washburn County, WI","55131":"Washington County, WI","55133":"Waukesha County, WI","55135":"Waupaca County, WI","55137":"Waushara County, WI","55139":"Winnebago County, WI","55141":"Wood County, WI","56001":"Albany County, WY","56003":"Big Horn County, WY","56005":"Campbell County, WY","56007":"Carbon County, WY","56009":"Converse County, WY","56011":"Crook County, WY","56013":"Fremont County, WY","56015":"Goshen County, WY","56017":"Hot Springs County, WY","56019":"Johnson County, WY","56021":"Laramie County, WY","56023":"Lincoln County, WY","56025":"Natrona County, WY","56027":"Niobrara County, WY","56029":"Park County, WY","56031":"Platte County, WY","56033":"Sheridan County, WY","56035":"Sublette County, WY","56037":"Sweetwater County, WY","56039":"Teton County, WY","56041":"Uinta County, WY","56043":"Washakie County, WY","56045":"Weston County, WY","60010":"Eastern District, AS","60020":"Manu\'a District, AS","60030":"Rose Island, AS","60040":"Swains Island, AS","60050":"Western District, AS","66010":"Guam, GU","69085":"Northern Islands, MP","69100":"Rota, MP","69110":"Saipan, MP","69120":"Tinian, MP","72001":"Adjuntas County, PR","72003":"Aguada County, PR","72005":"Aguadilla County, PR","72007":"Aguas Buenas County, PR","72009":"Aibonito County, PR","72011":"Anasco County, PR","72013":"Arecibo County, PR","72015":"Arroyo County, PR","72017":"Barceloneta County, PR","72019":"Barranquitas County, PR","72021":"Bayamo\'n County, PR","72023":"Cabo Rojo County, PR","72025":"Caguas County, PR","72027":"Camuy County, PR","72029":"Canovanas County, PR","72031":"Carolina County, PR","72033":"Catano County, PR","72035":"Cayey County, PR","72037":"Ceiba County, PR","72039":"Ciales County, PR","72041":"Cidra County, PR","72043":"Coamo County, PR","72045":"Comerio County, PR","72047":"Corozal County, PR","72049":"Culebra County, PR","72051":"Dorado County, PR","72053":"Fajardo County, PR","72054":"Florida County, PR","72055":"Guanica County, PR","72057":"Guayama County, PR","72059":"Guayanilla County, PR","72061":"Guaynabo County, PR","72063":"Gurabo County, PR","72065":"Hatillo County, PR","72067":"Hormigueros County, PR","72069":"Humacao County, PR","72071":"lsabela County, PR","72073":"Jayuya County, PR","72075":"Juana Diaz County, PR","72077":"Juncos County, PR","72079":"Lajas County, PR","72081":"Lares County, PR","72083":"Las Marias County, PR","72085":"Las Piedras County, PR","72087":"Loiza County, PR","72089":"Luquillo County, PR","72091":"Manati County, PR","72093":"Maricao County, PR","72095":"Maunabo County, PR","72097":"Mayaguez County, PR","72099":"Moca County, PR","72101":"Morovis County, PR","72103":"Naguabo County, PR","72105":"Naranjito County, PR","72107":"Orocovis County, PR","72109":"Patillas County, PR","72111":"Penuelas County, PR","72113":"Ponce County, PR","72115":"Quebradillas County, PR","72117":"Rincon County, PR","72119":"Rio Grande County, PR","72121":"Sabana Grande County, PR","72123":"Salinas County, PR","72125":"San German County, PR","72127":"San Juan County, PR","72129":"San Lorenzo County, PR","72131":"San Sebastian County, PR","72133":"Santa Isabel County, PR","72135":"Toa Alta County, PR","72137":"Toa Baja County, PR","72139":"Trujillo Alto County, PR","72141":"Utuado County, PR","72143":"Vega Alta County, PR","72145":"Vega Baja County, PR","72147":"Vieques County, PR","72149":"Villalba County, PR","72151":"Yabucoa County, PR","72153":"Yauco County, PR","78010":"St. Croix, VI","78020":"St. John, VI","78030":"St. Thomas, VI","64002":"Chuuk*, FM","64005":"Kosrae, FM","64040":"Pohnpeit*, FM","64060":"Yap, FM","68007":"Ailinginae, MH","68010":"Ailinglaplap, MH","68030":"Ailuk, MH","68040":"Arno, MH","68050":"Aur, MH","68060":"Bikar, MH","68070":"Bikini, MH","68073":"Bokak, MH","68080":"Ebon, MH","68090":"Enewetak, MH","68100":"Erikub, MH","68110":"Jabat, MH","68120":"Jaluit, MH","68130":"Jemo*, MH","68140":"Kili, MH","68150":"Kwajalein, MH","68160":"Lae, MH","68170":"Lib, MH","68180":"Likiep, MH","68190":"Majuro, MH","68300":"Maloelap, MH","68310":"Mejit, MH","68320":"Mili, MH","68330":"Namorik, MH","68340":"Namu, MH","68350":"Rongelap, MH","68360":"Rongrik, MH","68385":"Toke, MH","68390":"Ujae, MH","68400":"Ujelang, MH","68410":"Utrik, MH","68420":"Wotho, MH","68430":"Wotle, MH","70002":"Aimeliik, PW","70004":"Airai, PW","70010":"Angaur, PW","70050":"Hatoboheit*, PW","70100":"Kayangel, PW","70150":"Koror, PW","70212":"Melekeok*, PW","70214":"Ngaraard, PW","70218":"Ngarchelong, PW","70222":"Ngardmau, PW","70224":"Ngatpang, PW","70226":"Ngchesar, PW","70227":"Ngernmlengui*, PW","70228":"Ngiwal, PW","70350":"Peleliu, PW","70370":"Sonsorol, PW","74050":"Baker Island, UM","74100":"Howland Island, UM","74150":"Jarvis Island, UM","74200":"Johnston Island, UM","74250":"Kingman Reef, UM","74300":"Midway Islands, UM","74350":"Navassa Island, UM","74400":"Palmyra Atoll, UM","74450":"Wake Island, UM","75031":"Caribbean from 11N to 15N between 72W and 80W including Colombia Basin, AM","75013":"Caribbean N of 18N between 76W and 85W including Cayman Basin, AM","75037":"Tropical N Atlantic from 7N and 15N between 55W and 60W, AM","75121":"Atlantic from 22N to 27N between 65W and 70W, AM","75011":"Caribbean Nof 18N W of 85W including Yucatan Basin, AM","75017":"Gulf of Honduras, AM","75019":"Caribbean from 15N to 18N between 80W and 85W, AM","75021":"Caribbean from 15N to 18N between 72W and 80W, AM","75015":"Caribbean approaches to the Windward Passage, AM","75039":"SW Caribbean S of 11N including the approaches to the Panama Canal, AM","75029":"W Central Caribbean from 11N to 15N W of 80W, AM","75023":"Caribbean N of 15N between 64W and 72W, AM","75027":"Tropical N Atlantic from 15N to 19N between 55W and 60W, AM","75113":"Atlantic from 27N to 31N between 70W and 77W, AM","75125":"Atlantic S of 22N between 65W and 70W including Puerto Rico Trench, AM","75123":"Atlantic S of 22N W of 70W including approaches to the Windward Passage, AM","75025":"Offshore Waters Leeward Islands, AM","75035":"Offshore Waters Windward Islands including Trinidad and Tobago, AM","75117":"Bahamas including Cay Sal Bank, AM","75033":"Caribbean S of 15N between 64W and 72W including Venezuela Basin, AM","75127":"Atlantic from 19N to 22N between 55W and 65W, AM","75119":"Atlantic from 22N to 27N E of Bahamas to 70W, AM","75115":"Atlantic from 27N to 31N between 65W and 70W, AM","75111":"Atlantic from 27N to 31N W of 77W, AM","73805":"Georges Bank between Cape Cod and 68W N of 1000 FM, AN","73810":"South of New England between the Great S Channel and Montauk Point to 1000 FM, AN","73820":"Hudson Canyon to Baltimore Canyon to 1000 FM, AN","73925":"Baltimore Canyon to Hatteras Canyon between 100 NM and 250 NM offshore, AN","57900":"Cape Flattery to Cape Shoalwater between 150 NM and 250 NM offshore, PZ","57915":"Florence, OR to Point St. George between 150 NM and 250 NM offshore, PZ","57920":"Point St. George to Point Arena between 150 NM and 250 NM offshore, PZ","57930":"Pigeon Point to Point Piedras Blancas between 150 NM and 250 NM offshore, PZ","57940":"Santa Cruz Island, CA to 120W between 150 NM and 250 NM offshore, PZ","77019":"Central Gulf from 22N to 26N between 87W and 94W, GM","77015":"NE Gulf N of 25N E of 87W, GM","77013":"N Central Gulf including Flower Garden Banks Marine Sanctuary, GM","77011":"NW Gulf including Stetson Bank, GM","77025":"E Bay of Campeche including Campeche Bank, GM","77017":"W Central Gulf from 22N to 26N W of 94W, GM","77021":"E Gulf from 22N to 25N E of 87W including Straits of Florida, GM","77023":"SW Gulf S of 22N W of 94W, GM","58510":"Eastern US Arctic Offshore, PK","58505":"Central US Arctic Offshore, PK","58500":"Western US Arctic Offshore, PK","58310":"Gulf of Alaska N of 55 Degrees N and E of 144 W, PK","58411":"Bering Sea Offshore W of 180 and E of the International Date Line, PK","58351":"Gulf of Alaska Offshore N of 57N and W of 144W, PK","58352":"Gulf of Alaska Offshore S of 57N N of 55N and W of 144W, PK","58413":"Bering Sea Offshore 171W to 180 and S of 56N, PK","58414":"Bering Sea Offshore E of 171W, PK","58412":"Bering Sea Offshore 171W to 180 and N of 56N, PK","59180":"Hawaiian Offshore Waters, PH","73800":"Gulf of Maine to the Hague Line, AN","73900":"Georges Bank between 68W and the Hague Line, AN","73815":"South of Long Island between Montauk Point and Sandy Hook to 1000 FM, AN","73905":"East of 69W to the Hague Line between 1000 FM and 39N, AN","73910":"East of 69W and S of 39N to 250 NM offshore, AN","73920":"Baltimore Canyon to 69W E of 1000 FM and S of 38.5N to 250 NM offshore, AN","73915":"Between 1000FM and 38.5 N W of 69 W, AN","73825":"Baltimore Canyon to Cape Charles Light to 100 NM offshore, AN","73828":"Cape Charles Light to Currituck Beach Light to 100 NM offshore, AN","73833":"Cape Hatteras to Cape Fear to 100 NM Offshore., AN","73830":"Currituck Beach Light to Cape Hatteras to 100 NM offshore, AN","73930":"Hatteras Canyon to Cape Fear between 100 NM and 250 NM offshore, AN","73835":"Cape Fear to 31N to 1000 FM, AN","73935":"Cape Fear to 31N E of 1000 FM to 250 NM offshore, AN","57840":"Santa Cruz Island, CA to San Clemente Island, CA between 60 NM and 150 NM offshore, PZ","57835":"Point Piedras Blancas to Santa Cruz Island, CA between 60 NM and 150 NM offshore, PZ","57935":"Point Piedras Blancas to Santa Cruz Island, CA between 150 NM and 250 NM offshore, PZ","57800":"Cape Flattery to Cape Shoalwater between 60 NM and 150 NM offshore, PZ","57905":"Cape Shoalwater to Cape Lookout between 150 NM and 250 NM offshore, PZ","57805":"Cape Shoalwater to Cape Lookout between 60 NM and 150 NM offshore, PZ","57910":"Cape Lookout to Florence, OR between 150 NM and 250 NM offshore, PZ","57810":"Cape Lookout to Florence, OR between 60 NM and 150 NM offshore, PZ","57815":"Florence, OR to Point St. George between 60 NM and 150 NM offshore, PZ","57820":"Point St. George to Point Arena between 60 NM and 150 NM offshore, PZ","57925":"Point Arena to Pigeon Point between 150 NM and 250 NM offshore, PZ","57825":"Point Arena to Pigeon Point between 60 NM and 150 NM offshore, PZ","57830":"Pigeon Point to Point Piedras Blancas between 60 NM and 150 NM offshore, PZ","57945":"San Clemente Island, CA to Guadalupe Island from 60 NM offshore W to 120W, PZ","59113":"Kauai Channel, PH","59112":"Kauai Leeward Waters, PH","77155":"Coastal waters from Baffin Bay to Port Mansfield TX out 20 NM, GM","77657":"Coastal waters from E Cape Sable to Chokoloskee FL out 20 NM, GM","77656":"Coastal waters from Chokoloskee to Bonita Beach FL out 20 NM, GM","77044":"Hawk Channel from W end of Seven Mile Bridge to Halfmoon Shoal out to the reef, GM","75671":"Waters from Deerfield Beach to Ocean Reef FL from 20 to 60 NM excluding the territorial waters of Bahamas, AM","77676":"Waters from Chokoloskee to Bonita Beach FL from 20 to 60 NM, GM","77876":"Waters from Bonita Beach to Englewood FL out 20 to 60 NM, GM","77873":"Waters from Englewood to Tarpon Springs FL out 20 to 60 NM, GM","77170":"Waters from Port Mansfield TX to the Rio Grande River from 20 to 60 NM, GM","77175":"Waters from Baffin Bay to Port Mansfield TX from 20 to 60 NM, GM","77270":"Waters from Baffin Bay to Port Aransas from 20 to 60 NM, GM","77275":"Waters from Port Aransas to Matagorda Ship Channel from 20 to 60 NM, GM","77370":"Waters from Freeport to Matagorda Ship Channel TX from 20 to 60 NM, GM","77250":"Coastal waters from Baffin Bay to Port Aransas out 20 NM, GM","77255":"Coastal waters from Port Aransas to Matagorda Ship Channel out 20 NM, GM","77350":"Coastal waters from Freeport to Matagorda Ship Channel TX out 20 NM, GM","77150":"Coastal waters from Port Mansfield TX to the Rio Grande River out 20 NM, GM","75710":"Atlantic Waters of Puerto Rico AND USVI from 10 NM to 19.5N, AM","75722":"Anegada Passage Southward to 17N, AM","61150":"Coastal waters of Tututila and Aunuu, PS","61151":"Coastal waters of Manua, PS","77052":"Straits of Florida from Ocean Reef to Craig Key out 20 NM, GM","77053":"Straits of Florida from Craig Key to W end of Seven Mile Bridge out 20 NM, GM","77054":"Straits of Florida from W end of Seven Mile Bridge to S of Halfmoon Shoal out 20 NM, GM","77075":"Straits of Florida from Halfmoon Shoal to 20 NM W of Dry Tortugas 20 to 60 NM out, GM","77073":"Straits of Florida from Craig Key to W end of Seven Mile Bridge 20 to 60 NM out, GM","77072":"Straits of Florida from Ocean Reef to Craig Key 20 to 60 NM out, GM","77033":"Gulf waters from E Cape Sable to Chokoloskee 20 to 60 NM out and beyond 5 fathoms, GM","77074":"Straits of Florida from W end of Seven Mile Bridge to S of Halfmoon Shoal 20 to 60 NM out, GM","77055":"Straits of Florida from Halfmoon Shoal to 20 NM W of Dry Tortugas out 20 NM, GM","77043":"Hawk Channel from Craig Key to W end of Seven Mile Bridge out to the reef, GM","77035":"Gulf of Mexico from W End of Seven Mile Bridge to Halfmoon Shoal out to 5 Fathoms, GM","77032":"Bayside and Gulf side from Craig Key to W End of Seven Mile Bridge, GM","75651":"Coastal waters from Deerfield Beach to Ocean Reef FL out 20 NM, AM","75550":"Flagler Beach to Volusia-Brevard County Line 0-20 nm, AM","65171":"Yap Coastal Waters, PM","65172":"Chuuk Coastal Waters, PM","65173":"Pohnpei Coastal Waters, PM","65174":"Kosrae Coastal Waters, PM","65181":"Majuro Coastal Waters, PM","65191":"Waters out to 40 Nautical Miles, PM","77450":"Coastal waters from Cameron LA to High Island TX out 20 NM, GM","77430":"Sabine Lake, GM","77355":"Coastal waters from High Island to Freeport TX out 20 NM, GM","75610":"Lake Okeechobee, AM","75650":"Coastal waters from Jupiter Inlet to Deerfield Beach FL out 20 NM, AM","75555":"Sebastian Inlet to Jupiter Inlet 0-20 nm, AM","73235":"Rhode Island Sound, AN","73236":"Narragansett Bay, AN","57576":"Waters from Point Pinos to Point Piedras Blancas 10-60 NM, PZ","57530":"San Pablo Bay, Suisun Bay, the W Delta and the San Francisco Bay N of the Bay Bridge, PZ","57531":"San Francisco Bay S of the Bay Bridge, PZ","59111":"Kauai Windward Waters, PH","59110":"Kauai NW Waters, PH","59116":"Kaiwi Channel, PH","59115":"Oahu Leeward Waters, PH","59114":"Oahu Windward Waters, PH","59118":"Maui County Leeward Waters, PH","59120":"Pailolo Channel, PH","59117":"Maui County Windward Waters, PH","59124":"Big Island SE Waters, PH","59119":"Maalaea Bay, PH","59121":"Alenuihaha Channel, PH","59123":"Big Island Leeward Waters, PH","59122":"Big Island Windward Waters, PH","75712":"Coastal Waters of Northern Puerto Rico out 10 NM, AM","75725":"Coastal Waters of Southern USVI, Vieques, and Eastern Puerto Rico out 10 NM, AM","75715":"Coastal Waters of Northern USVI and Culebra out 10 NM, AM","75745":"Coastal Waters OF Southwestern Puerto Rico out 10 NM, AM","75735":"Coastal Waters of Southern Puerto Rico out 10 NM, AM","75742":"Coastal Waters OF Northwestern Puerto Rico out 10 NM, AM","75741":"Mona Passage Southward to 17N, AM","75732":"Caribbean Waters of Puerto Rico from 10 NM to 17N, AM","65161":"Koror Palau Coastal Waters, PM","65151":"Guam Coastal Waters, PM","65152":"Rota Coastal Waters, PM","65153":"Tinian Coastal Waters, PM","65154":"Saipan Coastal Waters, PM","92779":"Lake Michigan from Wilmette Harbor to Michigan City in 5NM offshore to Mid Lake, LM","92080":"Lake Michigan Michigan City IN to St. Joseph MI 5 NM offshore to mid-line of lake., LM","92777":"Lake Michigan from Winthrop Harbor to Wilmette Harbor IL 5NM offshore to Mid Lake, LM","92878":"Lake Michigan from St Joseph to S Haven MI 5NM offshore to Mid Lake, LM","92675":"Lake Michigan from Wind Point WI to Winthrop Harbor IL 5NM offshore to Mid Lake, LM","92876":"Lake Michigan from S Haven to Holland MI 5NM offshore to Mid lake, LM","92673":"Lake Michigan from N Point Light to Wind Point WI 5NM offshore to Mid Lake, LM","92671":"Lake Michigan from Port Washington to N Point Light WI 5NM offshore to Mid Lake, LM","92669":"Lake Michigan from Sheboygan to Port Washington WI 5NM offshore to Mid Lake, LM","92870":"Lake Michigan from Whitehall to Pentwater MI 5NM offshore to Mid Lake, LM","92845":"South Haven to Holland MI, LM","92846":"Holland to Grand Haven MI, LM","92847":"Grand Haven to Whitehall MI, LM","92745":"Burns Harbor to Michigan City IN, LM","92043":"New Buffalo MI to St Joseph MI, LM","92744":"Gary to Burns Harbor IN, LM","93442":"Harbor Beach to Port Sanilac MI, LH","94460":"Lake St. Clair Open Lake (U.S. Portion), LC","93443":"Port Sanilac to Port Huron MI, LH","94422":"St. Clair River, LC","77472":"Waters from Intracoastal City to Cameron LA from 20 to 60 NM, GM","77475":"Waters from Lower Atchafalaya River to Intracoastal City LA from 20 to 60 NM, GM","77570":"Coastal waters from Port Fourchon Louisiana to Lower Atchafalaya River LA from 20 to 60 NM, GM","77375":"Waters from High Island to Freeport TX from 20 to 60 NM, GM","77470":"Waters from Cameron LA to High Island TX from 20 to 60 NM, GM","77577":"Coastal waters from Pascagoula Mississippi to Stake Island Louisiana out 20 to 60 NM, GM","77572":"Coastal waters from SW Pass of the Mississippi River to Port Fourchon Louisiana from 20 to 60 NM, GM","97030":"Lower Niagara River, LO","77335":"Galveston Bay, GM","77435":"Vermilion Bay, GM","73237":"Block Island Sound, AN","73256":"Coastal Waters from Montauk NY to Marthas Vineyard extending out to 20 nm S of Block Island, AN","73255":"Coastal Waters extending out to 25 nm S of Marthas Vineyard and Nantucket, AN","73234":"Buzzards Bay, AN","75330":"Charleston Harbor, AM","77034":"Gulf of Mexico including Dry Tortugas and Rebecca Shoal Channel, GM","75630":"Biscayne Bay, AM","73543":"Tangier Sound and the inland waters surrounding Bloodsworth Island, AN","73230":"Boston Harbor, AN","91144":"Two Harbors to Duluth MN, LS","91145":"Duluth MN to Port Wing WI, LS","91143":"Silver Bay Harbor to Two Harbors MN, LS","91142":"Taconite Harbor to Silver Bay Harbor MN, LS","91141":"Grand Marais to Taconite Harbor MN, LS","91140":"Grand Portage to Grand Marais MN, LS","91146":"Port Wing to Sand Island WI, LS","91147":"Sand Island to Bayfield WI, LS","91121":"Chequamegon Bay-Bayfield to Oak Point WI, LS","91148":"Oak Point to Saxon Harbor WI, LS","91162":"Lake Superior W of a line from Saxon Harbor WI to Grand Portage MN beyond 5NM, LS","91240":"Saxon Harbor WI to Black River MI, LS","91241":"Black River To Ontonagon MI, LS","57570":"Waters from Point Arena to Point Reyes 10-60 NM, PZ","57475":"Waters from Cape Mendocino to Pt. Arena CA from 10 to 60 nm, PZ","57450":"Coastal waters from Pt. St. George to Cape Mendocino CA out 10 nm, PZ","57410":"Humboldt Bay Bar, PZ","57470":"Waters from Pt. St. George to Cape Mendocino CA from 10 to 60 nm, PZ","57376":"Waters from Cape Blanco OR to Pt. St. George CA from 10 to 60 nm, PZ","57370":"Waters from Florence to Cape Blanco OR from 10 to 60 nm, PZ","57255":"Coastal waters from Cascade Head to Florence OR out 10 nm, PZ","57275":"Waters from Cascade Head to Florence OR from 10 to 60 nm, PZ","57270":"Waters from Cape Shoalwater WA to Cascade Head OR from 10 to 60 nm, PZ","57176":"Coastal Waters From Point Grenville To Cape Shoalwater 10 To 60 Nm, PZ","57173":"Waters From James Island To Point Grenville 10 To 60 Nm, PZ","57210":"Columbia River Bar, PZ","57350":"Coastal waters from Florence to Cape Blanco OR out 10 nm, PZ","57356":"Coastal waters from Cape Blanco OR to Pt. St. George CA out 10 nm, PZ","57545":"Coastal Waters from Point Reyes to Pigeon Point California out to 10 nm, PZ","57540":"Coastal Waters from Point Arena to Point Reyes California out to 10 nm, PZ","57455":"Coastal waters from Cape Mendocino to Pt. Arena CA out 10 nm, PZ","57170":"Coastal Waters From Cape Flattery To James Island 10 To 60 Nm, PZ","57130":"West Entrance U.S. Waters Strait Of Juan De Fuca, PZ","57131":"Central U.S. Waters Strait Of Juan De Fuca, PZ","57135":"Puget Sound and Hood Canal, PZ","57250":"Coastal waters from Cape Shoalwater WA to Cascade Head OR out 10 nm, PZ","57156":"Coastal Waters From Point Grenville To Cape Shoalwater Out 10 Nm, PZ","57150":"Coastal Waters From Cape Flattery To James Island Out 10 Nm, PZ","91245":"Manitou Island to Point Isabelle MI, LS","91246":"Point Isabelle to Lower Entrance of Portage Canal MI, LS","91247":"Portage Lake to Huron Island MI to Lower Entrance of Portage Canal To Huron Islands MI Including Keweenaw and Huron Bays, LS","91248":"Huron Islands to Marquette MI, LS","91249":"Marquette to Munising MI, LS","91250":"Munising to Grand Marais MI, LS","91251":"Grand Marais to Whitefish Point MI, LS","91265":"Lake Superior W of Line from Manitou Island to Marquette MI Beyond 5NM from shore, LS","92522":"Green Bay S of line from Oconto WI to Little Sturgeon Bay WI, LM","92521":"Green Bay S of line from Cedar River to Rock Island Passage and N of a line from Oconto WI to Little Sturgeon Bay WI, LM","92221":"Green Bay N of line from Cedar River MI to Rock Island Passage, LM","92541":"Rock Island Passage to Sturgeon Bay WI, LM","92250":"5NM E of a line from Fairport MI to Rock Island Passage, LM","91321":"Whitefish Bay (U.S. Portion)/Whitefish Point to Point Iroquois MI, LS","91322":"St. Marys River Point Iroquois to E. Potagannissing Bay, LS","92248":"Seul Choix Point to Point Detour MI, LM","93346":"St Ignace to False Detour Channel, LH","92341":"Seul Choix Point to 5NM W of Mackinac Bridge, LM","93361":"Lake Huron from 5NM E of Mackinac Bridge to Presque Isle Lt to the US/Canadian border beyond 5 NM from shore, LH","93347":"5NM E of Mackinac Bridge to Presque Isle Light MI including Bois Blanc Island, LH","93345":"Straits of Mackinac within 5 nm of Mackinac Bridge including Mackinac Island, LH","92323":"Grand Traverse Bay S of a line Grand Traverse Light to Norwood MI, LM","92364":"Lake Michigan from Charlevoix to Point Betsie MI 5NM Offshore to mid lake, LM","92362":"Lake Michigan S of a line from Seul Choix Point to the Mackinac Bridge and N of a line from Charlevoix MI to S Fox Island 5NM offshore, LM","92344":"Sleeping Bear Point to Grand Traverse Light MI, LM","92342":"Norwood MI to 5NM W of Mackinac Bridge including Little Traverse Bay, LM","91266":"Lake Superior E of a line from Manitou Island to Marquette MI and W of a line from Grand Marais MI to the US/Canadian Border Beyond 5NM from shore, LS","91267":"Lake Superior from Grand Marais MI to Whitefish Point MI 5NM off shore to the US/Canadian border, LS","92643":"Sheboygan to Port Washington WI, LM","92543":"Two Rivers to Sheboygan WI, LM","92542":"Sturgeon Bay to Two Rivers WI, LM","92346":"Manistee to Point Betsie MI, LM","94423":"Detroit River, LC","96444":"Michigan Waters of Lake Erie from Detroit River to N Cape MI, LE","96142":"Maumee Bay to Reno Beach OH, LE","96163":"Reno Beach to The Islands OH beyond 5NM off shoreline to US-Canadian border, LE","96143":"Reno Beach to The Islands OH, LE","96144":"The Islands to Vermilion OH, LE","96145":"Vermilion to Avon Point OH, LE","96146":"Avon Point to Willowick OH, LE","92567":"Lake Michigan from Two Rivers to Sheboygan WI 5NM offshore to Mid Lake, LM","92868":"Lake Michigan from Pentwater to Manistee MI 5NM offshore to Mid Lake, LM","92565":"Lake Michigan from Sturgeon Bay to Two Rivers WI 5NM offshore to Mid Lake, LM","92366":"Lake Michigan from Point Betsie to Manistee MI 5NM offshore to Mid Lake, LM","92563":"Lake Michigan from Rock Island Passage to Sturgeon Bay WI 5NM offshore to mid lake, LM","92046":"Michigan City IN to New Buffalo MI, LM","92844":"St Joseph to S Haven MI, LM","92743":"Calumet Harbor IL to Gary IN, LM","92742":"Northerly Island to Calumet Harbor IL, LM","92741":"Wilmette Harbor to Northerly Island IL, LM","92740":"Winthrop Harbor to Wilmette Harbor IL, LM","92646":"Wind Point WI to Winthrop Harbor IL, LM","92645":"North Point Light to Wind Point WI, LM","92644":"Port Washington to N Point Light WI, LM","93348":"Presque Isle Light to Sturgeon Pt MI Including Thunder Bay National Marine Sanctuary, LH","93349":"Sturgeon Pt to Alabaster MI, LH","93421":"Outer Saginaw Bay SW of Alabaster to Port Austin MI to Inner Saginaw Bay, LH","93422":"Inner Saginaw Bay SW of Point Au Gres to Bay Port MI, LH","93363":"Lake Huron from Sturgeon Point to Alabaster MI 5NM off shore to US/Canadian border, LH","93441":"Port Austin to Harbor Beach MI, LH","93462":"Lake Huron from Port Austin to Harbor Beach 5NM Off Shore to the US/Canadian border, LH","92261":"Lake Michigan from Seul Choix Point to Rock Island Passage 5NM offshore to Mid Lake, LM","93362":"Lake Huron from Presque Isle Lt. to Sturgeon Point MI 5NM off shore to US/Canadian border, LH","93463":"Lake Huron from Harbor Beach to Port Sanilac 5NM Off Shore to US/Canadian border, LH","96147":"Willowick to Geneva-on-the Lake OH, LE","96148":"Geneva-on-the-Lake to Conneaut OH, LE","96149":"Conneaut OH to Ripley NY, LE","96040":"Ripley to Dunkirk NY, LE","97043":"Hamlin Beach to Sodus Bay NY, LO","97044":"Sodus Bay to Mexico Bay NY, LO","93464":"Lake Huron from Port Sanilac to Port Huron 5NM Off Shore to US/Canadian border, LH","96162":"Detroit River Lt. to Maumee Bay OH to Reno Beach OH beyond 5NM offshoreline to US-Canadian border, LE","96164":"The Islands to Vermilion OH beyond 5 nm off shoreline to US-Canadian border, LE","96165":"Vermilion to Avon Point OH beyond 5 nm off shoreline to US-Canadian border, LE","96166":"Avon Point to Willowick OH beyond 5 nm off shoreline to US-Canadian border, LE","96167":"Willowick to Geneva-on-the-Lake OH beyond 5NM off shoreline to US-Canadian border, LE","96041":"Dunkirk to Buffalo NY, LE","96020":"Upper Niagara River and Buffalo Harbor, LE","98022":"St. Lawrence River above Ogdensburg NY, SL","98024":"St. Lawrence River from Ogdensburg to St. Regis NY, SL","97045":"Mexico Bay NY to the St. Lawrence River, LO","58125":"Prince William Sound, PK","96168":"Geneva-on-the-Lake to Conneaut OH beyond 5 nm off shoreline to US-Canadian border, LE","96169":"Conneaut OH to Ripley NY beyond 5 nm off shoreline to US-Canadian border, LE","96061":"Ripley to Buffalo NY extending from 5NM off shoreline to US-Canadian border, LE","97042":"Niagara River to Hamlin Beach NY, LO","97062":"Niagara River to Hamlin Beach NY beyond 5NM off shoreline to US-Canadian border, LO","97063":"Hamlin Beach to Sodus Bay NY beyond 5NM off shoreline to US-Canadian border, LO","97064":"Sodus Bay to Mexico Bay NY beyond 5NM off shoreline to US-Canadian border, LO","97065":"Mexico Bay NY to the St. Lawrence River beyond 5NM off shoreline to US-Canadian border, LO","92849":"Pentwater to Manistee MI, LM","92848":"Whitehall to Pentwater MI, LM","92345":"Point Betsie to Sleeping Bear Point MI, LM","73172":"Waters from Port Clyde ME to Cape Elizabeth ME from 25 to 40 nm, AN","73271":"Ocean Waters from Provincetown to Nantucket from 20 to 35 NM offshore, AN","73070":"Waters from Eastport ME to Schoodic Point, ME from 25 to 40 nm, AN","73273":"Ocean Waters from Montauk NY to Marthas Vineyard from 25 to 40 NM offshore, AN","73272":"Ocean Waters from Marthas Vineyard to Nantucket from 25 to 45 NM offshore, AN","73370":"Waters from Moriches Inlet NY to Montauk Point NY from 20 to 40 NM, AN","75370":"Waters from S Santee River SC to Edisto Beach SC extending from 20 nm to 40 nm, AM","75470":"Waters from Altamaha Sound GA to Fernandina Beach FL from 20 to 60 NM, AM","75374":"Waters from Savannah GA to Altamaha Sound GA extending from 20 nm to 60 nm, AM","75472":"Waters from Fernandina Beach to St. Augustine FL from 20 to 60 NM, AM","75474":"Waters from St. Augustine to Flagler Beach FL from 20 to 60 NM, AM","73542":"Patuxent River to Broomes Island MD, AN","73534":"Chesapeake Bay from Drum Point MD to Smith Point VA, AN","73654":"Coastal waters from Parramore Island to Cape Charles Light VA out 20 nm, AN","73632":"Chesapeake Bay from New Point Comfort to Little Creek VA, AN","73636":"York River, AN","91242":"Ontonagon to Upper Entrance of Portage Canal MI, LS","91243":"Upper Entrance of Portage Canal to Eagle River MI, LS","91244":"Eagle River to Manitou Island MI, LS","77557":"Coastal waters from Pascagoula Mississippi to Stake Island out 20 NM, GM","92874":"Lake Michigan from Holland to Grand Haven MI 5NM offshore to Mid Lake, LM","92872":"Lake Michigan from Grand Haven to Whitehall MI 5NM offshore to Mid Lake, LM","57565":"Coastal Waters from Point Pinos to Point Piedras Blancas California out to 10 nm, PZ","57560":"Coastal Waters from Pigeon Point to Point Pinos California out to 10 nm, PZ","57535":"Monterey Bay, PZ","75352":"Coastal waters from Edisto Beach SC to Savannah GA out 20 nm, AM","75354":"Coastal waters from Savannah GA to Altamaha Sound GA out 20 nm ...including Grays Reef National Marine Sanctuary, AM","77770":"Waters from Okaloosa-Walton County Line to Mexico Beach from 20 to 60 NM, GM","77775":"Waters from Suwannee River to Apalachicola FL from 20 to 60 NM, GM","77870":"Waters from Tarpon Springs to Suwannee River FL out 20 to 60 NM, GM","77575":"Coastal Waters from Stake Island LA to SW Pass of the Mississippi River from 20 to 60 nm, GM","57650":"East Santa Barbara Channel from Pt. Conception to Pt. Mugu CA including Santa Cruz Island, PZ","57673":"Waters from Pt. Sal to Santa Cruz Island CA and westward 60 nm including San Miguel and Santa Rosa Islands, PZ","57645":"Point Piedras Blancas to Point Sal westward out to 10 NM, PZ","77452":"Coastal waters from Intracoastal City to Cameron LA out 20 NM, GM","77432":"Calcasieu Lake, GM","77455":"Coastal waters from Lower Atchafalaya River to Intracoastal City LA out 20 NM, GM","77031":"Florida Bay including Barnes Sound, Blackwater Sound, and Buttonwood Sound, GM","77042":"Hawk Channel from Ocean Reef to Craig Key out to the reef, GM","75552":"Volusia-Brevard County Line to Sebastian Inlet 0-20 nm, AM","73233":"Vineyard Sound, AN","73232":"Nantucket Sound, AN","73254":"Coastal waters from Provincetown MA to Chatham MA to Nantucket MA out 20 nm, AN","75670":"Waters from Jupiter Inlet to Deerfield Beach FL from 20 to 60 NM, AM","77670":"Waters from Pensacola FL to Pascagoula MS from 20 to 60 NM, GM","77675":"Waters from Okaloosa-Walton County Line to Pensacola FL from 20 to 60 NM, GM","57110":"Grays Harbor Bar, PZ","57153":"Coastal Waters From James Island To Point Grenville Out 10 Nm, PZ","57655":"Inner waters from Point Mugu to San Mateo Pt. CA including Santa Catalina and Anacapa Islands, PZ","77135":"Laguna Madre From 5 nm N Of Port Mansfield To Baffin Bay TX, GM","77132":"Laguna Madre From The Arroyo Coloardo To 5 NM N Of Port Mansfield TX, GM","77130":"Laguna Madre From the Port Of Brownsville to the Arroyo Colorado, GM","77230":"Bays and Waterways from Baffin Bay to Port Aransas, GM","77330":"Matagorda Bay, GM","77765":"Coastal waters from Suwannee River to Keaton Beach out 20 NM, GM","77730":"Apalachee Bay or Coastal Waters From Keaton Beach to Ochlockonee River Fl out to 20 Nm, GM","77850":"Coastal waters from Tarpon Springs to Suwannee River FL out 20 NM, GM","77853":"Coastal waters from Englewood to Tarpon Springs FL out 20 NM, GM","77830":"Tampa Bay waters, GM","77856":"Coastal waters from Bonita Beach to Englewood FL out 20 NM, GM","77836":"Charlotte Harbor and Pine Island Sound, GM","73231":"Cape Cod Bay, AN","73251":"Massachusetts Bay and Ipswich Bay, AN","58138":"Shelikof Strait, PK","58245":"Flaxman Island to Demarcation Point, PK","58240":"Cape Halkett to Flaxman Island, PK","58235":"Point Franklin to Cape Halkett, PK","58230":"Cape Beaufort to Point Franklin, PK","58225":"Cape Thompson to Cape Beaufort, PK","58150":"Sitkinak to Castle Cape, PK","58160":"Bristol Bay, PK","58155":"Castle Cape to Cape Sarichef, PK","58165":"Port Heiden to Cape Sarichef, PK","58170":"Cape Sarichef to Nikoski Bering Side, PK","58179":"Pribilof Islands Nearshore Waters, PK","58172":"Cape Sarichef to Nikoski Pacific Side, PK","58174":"Nikolski to Seguam Pacific Side, PK","58173":"Nikolski to Seguam Bering Side, PK","58176":"Seguam to Adak Pacific Side, PK","58175":"Seguam to Adak Bering Side, PK","58177":"Adak to Kiska, PK","58171":"Unalaska Bay, PK","77235":"Bays and Waterways from Port Aransas to Port O\'Connor, GM","77550":"Coastal Waters from Port Fourchon LA to Lower Atchafalaya River LA out 20 nm, GM","77555":"Coastal Waters from Boothville LA to SW Pass of the Mississippi River out 20 nm, GM","77552":"Coastal waters from the SW Pass of the Mississippi River to Port Fourchon Louisiana out 20 NM, GM","58178":"Kiska to Attu, PK","58220":"Wales to Cape Thompson, PK","58215":"Kotzebue Sound, PK","58200":"Norton Sound, PK","58210":"Dall Point to Wales, PK","58180":"Kuskokwim Delta and Etolin Strait, PK","58181":"North and W of Nunivak Island, PK","58185":"St Matthew Island Waters, PK","58129":"Western Prince William Sound, PK","58128":"Valdez Arm, PK","58127":"Valdez Narrows, PK","58126":"Port of Valdez, PK","58136":"Chiniak Bay, PK","58137":"Marmot Bay, PK","58121":"Resurrection Bay, PK","57132":"East Entrance U.S. Waters Strait Of Juan De Fuca, PZ","57134":"Admiralty Inlet, PZ","57133":"Northern Inland Waters Including The San Juan Islands, PZ","57676":"Outer waters from Santa Cruz Island to San Clemente Island to 60 NM offshore including San Nicolas and Santa Barbara Islands, PZ","57750":"Coastal Waters from San Mateo Point to the Mexican Border and out to 30 nm, PZ","57775":"Waters from San Mateo point to the Mexican Border Extending 30 to 60 nm out including San Clemente Island, PZ","57575":"Waters from Pigeon Point to Point Pinos 10-60 NM, PZ","57571":"Waters from Point Reyes to Pigeon Point 10-60 NM, PZ","61152":"Coastal waters of Swain\'s Island, PS","75575":"Sebastian Inlet to Jupiter Inlet 20-60 nm, AM","75570":"Flagler Beach to Volusia-Brevard County Line 20-60 nm, AM","75572":"Volusia-Brevard County Line to Sebastian Inlet 20-60 nm, AM","75178":"Waters from Cape Lookout to Surf City NC from 20 to 40 nm, AM","77530":"Lake Pontchartrain and Lake Maurepas, GM","75452":"Coastal waters from Fernandina Beach to St. Augustine FL out 20 NM, AM","75454":"Coastal waters from St. Augustine to Flagler Beach FL out 20 NM, AM","75450":"Coastal waters from Altamaha Sound to Fernandina Beach FL out 20 NM, AM","75350":"Coastal waters from S Santee River to Edisto Beach SC out 20 nm, AM","75274":"Waters from Little River Inlet to Murrells Inlet SC from 20 to 40 nm, AM","75254":"Coastal waters from Little River Inlet to Murrells Inlet SC out 20 nm, AM","75256":"Coastal waters from Murrells Inlet to S Santee River SC out 20 nm, AM","75250":"Coastal waters from Surf City to Cape Fear NC out 20 nm, AM","75156":"S of Ocracoke Inlet NC to Cape Lookout NC out to 20 nm, AM","75158":"S of Cape Lookout NC to Surf City NC out to 20 nm, AM","75252":"Coastal waters from Cape Fear NC to Little River Inlet SC out 20 nm, AM","73638":"James River from James River Bridge to Hampton Roads Bridge-Tunnel, AN","73637":"James River from Jamestown to the James River Bridge, AN","73631":"Chesapeake Bay from Windmill Point to New Point Comfort VA, AN","73250":"Coastal waters E of Ipswich Bay and the Stellwagen Bank National Marine Sanctuary, AN","73154":"Coastal Waters from Cape Elizabeth, ME to Merrimack River, MA out 25 NM, AN","73153":"Casco Bay, AN","57670":"Point Piedras Blancas to Point Sal from 10 to 60 NM, PZ","73270":"Ocean Waters from the Merrimack River to Plymouth from 40 to 60 NM offshore, AN","73676":"Waters from Cape Charles Light to Virginia - N Carolina Border from 20 to 40 nm, AN","73635":"Rappahannock River from Urbanna to Windmill Point, AN","73475":"Waters from Cape May NJ to Fenwick Island DE out 20 to 40 nm, AN","73630":"Chesapeake Bay from Smith Point to Windmill Point VA, AN","73650":"Coastal waters from Fenwick Island DE to Chincoteague VA out 20 nm, AN","73455":"Coastal waters from Cape Henlopen to Fenwick Island DE out 20 nm, AN","73652":"Coastal waters from Chincoteague to Parramore Island VA out 20 nm, AN","73152":"Coastal Waters from Port Clyde, ME to Cape Elizabeth, ME out 25 NM, AN","73150":"Coastal Waters from Stonington, ME to Port Clyde, ME out 25 NM, AN","73051":"Coastal Waters from Schoodic Point, ME to Stonington, ME out 25 NM, AN","73050":"Coastal Waters from Eastport, ME to Schoodic Point, ME out 25 NM, AN","73151":"Penobscot Bay, AN","73052":"Intra Coastal Waters from Schoodic Point, ME to Stonington, ME, AN","91263":"Lake Superior from Saxon Harbor WI to Upper Entrance to Portage Canal MI 5NM off shore to the US/Canadian border including Isle Royal National Park, LS","91264":"Lake Superior from Upper Entrance to Portage Canal to Manitou Island MI 5NM off shore to the US/Canadian Border, LS","73071":"Waters from Schoodic Point, ME to Stonington ME from 25 to 40 nm, AN","73170":"Waters from Stonington ME to Port Clyde ME from 25 to 40 nm, AN","73174":"Waters from Cape Elizabeth ME to Merrimack River MA from 25 to 40 nm, AN","73373":"Waters from Fire Island Inlet NY to Moriches Inlet NY from 20 to 40 NM, AN","73375":"Waters from Sandy Hook NJ to Fire Island Inlet out 20 to 40 nm, AN","73470":"Waters from Sandy Hook NJ to Manasquan Inlet NJ out 20 to 40 nm, AN","73471":"Waters from Manasquan Inlet NJ to Little Egg Inlet NJ out 20 to 40 nm, AN","73472":"Waters from Little Egg Inlet NJ to Great Egg Inlet NJ out 20 to 40 nm from 20 to 40 NM, AN","73473":"Waters from Great Egg Inlet NJ to Cape May NJ out 20 to 40 nm, AN","73670":"Waters from Fenwick Island DE to Chintoteague VA from 20 to 40 nm, AN","73672":"Waters from Chincoteague VA to Parramore Island VA from 20 to 40 nm, AN","73674":"Waters from Parramore Island VA to Cape Charles Light VA from 20 to 40 nm, AN","73678":"Waters from NC VA border to Currituck Beach Light NC from 20 to 40 nm, AN","75170":"Waters from Currituck Beach Light to Oregon Inlet NC from 20 to 40 nm, AM","75172":"Waters from Oregon Inlet to Cape Hatteras NC from 20 to 40 nm, AM","75174":"Waters from Cape Hatteras to Ocracoke Inlet NC from 20 to 40 nm, AM","75176":"Waters fromOcracoke Inlet to Cape Lookout NC from 20 to 40 nm, AM","75270":"Waters from Surf City to Cape Fear NC from 20 to 40 nm, AM","75276":"Waters from Murrells Inlet NC to S Santee River SC from 20 to 40 nm, AM","75372":"Waters from Edisto Beach SC to Savannah GA extending from 20 nm to 40 nm, AM","75272":"Waters from Cape Fear NC to Little River Inlet SC from 20 to 40 nm, AM","73430":"Delaware Bay waters N of E Point NJ to Slaughter Beach DE, AN","73454":"Coastal waters from Cape May NJ to Cape Henlopen DE out 20 nm, AN","73453":"Coastal waters from Great Egg Inlet to Cape May NJ out 20 nm, AN","73431":"Delaware Bay waters S of E Point NJ to Slaughter Beach DE, AN","73452":"Coastal waters from Little Egg Inlet to Great Egg Inlet NJ out 20 nm, AN","73450":"Coastal waters from Sandy Hook to Manasquan Inlet NJ out 20 nm, AN","73451":"Coastal waters from Manasquan Inlet to Little Egg Inlet NJ out 20 nm, AN","73338":"New York Harbor, AN","73335":"Long Island Sound W of New Haven CT/Port Jefferson NY, AN","73355":"Sandy Hook NJ to Fire Island Inlet NY out 20 nm, AN","73345":"South Shore Bays from Jones Inlet through Shinnecock Bay, AN","73353":"Fire Island Inlet NY to Moriches Inlet NY out 20 nm, AN","73350":"Moriches Inlet NY to Montauk Point NY out 20 nm, AN","73340":"Peconic and Gardiners Bays, AN","73330":"Long Island Sound E of New Haven CT/Port Jefferson NY, AN","58052":"Icy Cape to Cape Suckling, PK","58053":"Yakutat Bay, PK","58051":"Cape Fairweather to Icy Cape, PK","58036":"Clarence Strait, PK","58012":"Northern Lynn Canal, PK","58011":"Glacier Bay, PK","58013":"Southern Lynn Canal, PK","58031":"Stephens Passage, PK","58043":"Southeast Alaska Outside Waters From Cape Edgecumbe to Cape Fairweather, PK","58022":"Cross Sound, PK","58021":"Icy Strait, PK","58032":"Northern Chatham Strait, PK","58042":"Cape Decision to Cape Edgecumbe, PK","58033":"Southern Chatham Strait, PK","58034":"Frederick Sound, PK","58035":"Sumner Strait, PK","58041":"Dixon Entrance to Cape Decision, PK","58119":"Cape Suckling to Cape Cleare, PK","58132":"Shuyak Island To Sitkinak, PK","58131":"Barren Islands East, PK","58139":"Cook Inlet Kalgin Island to Point Bede, PK","58141":"Kachemak Bay, PK","58140":"Cook Inlet N Kalgin Island, PK","58130":"West of Barren Islands Including Kamishak Bay, PK","58120":"Cape Cleare to Gore Point, PK","77534":"Lake Borgne, GM","77538":"Breton Sound, GM","77532":"Mississippi Sound, GM","77536":"Chandeleur Sound, GM","77631":"South Mobile Bay, GM","77632":"Mississippi Sound, GM","77630":"North Mobile Bay, GM","77655":"Coastal waters from Okaloosa-Walton County Line to Pensacola FL out 20 NM, GM","77634":"Pensacola Bay Area including Santa Roas Sound, GM","77633":"Perdido Bay Area, GM","77650":"Coastal waters from Pensacola FL to Pascagoula MS out 20 NM, GM","77755":"Coastal Waters From Ochlockonee River to Apalachicola FL out to 20 Nm, GM","77750":"Coastal waters from Okaloosa-Walton County Line to Mexico Beach out 20 NM, GM","77636":"Eastern Choctawhatchee Bay, GM","75154":"S of Cape Hatteras NC to Ocracoke Inlet NC out to 20 nm, AM","75136":"Pamlico and Pungo Rivers, AM","75137":"Neuse and Bay Rivers, AM","75135":"Pamlico Sound, AM","75152":"S of Oregon Inlet NC to Cape Hatteras NC out to 20 nm, AM","75150":"S of Currituck Beach Light NC to Oregon Inlet NC out to 20 nm, AM","75130":"Albemarle Sound, AM","75131":"Alligator River, AM","73633":"Currituck Sound, AN","73658":"Coastal waters from NC VA border to Currituck Beach Light NC out 20 nm, AN","73656":"Coastal Waters from Cape Charles Light to Virginia-North Carolina border out to 20 nm, AN","73634":"Chesapeake Bay from Little Creek VA to Cape Henry VA including the Chesapeake Bay Bridge Tunnel, AN","73539":"Chester River to Queenstown MD, AN","73538":"Patapsco River including Baltimore Harbor, AN","73531":"Chesapeake Bay from Pooles Island to Sandy Point MD, AN","73530":"Chesapeake Bay N of Pooles Island MD, AN","73540":"Eastern Bay, AN","73533":"Chesapeake Bay from N Beach to Drum Point MD, AN","73532":"Chesapeake Bay from Sandy Point to N Beach MD, AN","73541":"Choptank River to Cambridge MD and the Little Choptank River, AN","73535":"Tidal Potomac from Key Bridge to Indian Head MD, AN","73536":"Tidal Potomac from Indian Head to Cobb Island MD, AN","73537":"Tidal Potomac from Cobb Island MD to Smith Point VA, AN","77752":"Coastal Waters from Mexico Beach to Apalachicola out 20 NM, GM","77772":"Waters from Mexico Beach to Apalachicola FL from 20 to 60 NM, GM","77635":"Western Choctawhatchee Bay, GM","99999":"Test Location","00000":"All of The United States","01000":"State of Alabama","02000":"State of Alaska","04000":"State of Arizona","05000":"State of Arkansas","06000":"State of California","08000":"State of Colorado","09000":"State of Connecticut","10000":"State of Delaware","11000":"District of Columbia","12000":"State of Florida","13000":"State of Georgia","15000":"State of Hawaii","16000":"State of Idaho","17000":"State of Illinois","18000":"State of Indiana","19000":"State of Iowa","20000":"State of Kansas","21000":"State of Kentucky","22000":"State of Louisiana","23000":"State of Maine","24000":"State of Maryland","25000":"State of Massachusetts","26000":"State of Michigan","27000":"State of Minnesota","28000":"State of Mississippi","29000":"State of Missouri","30000":"State of Montana","31000":"State of Nebraska","32000":"State of Nevada","33000":"State of New Hampshire","34000":"State of New Jersey","35000":"State of New Mexico","36000":"State of New York","37000":"State of North Carolina","38000":"State of North Dakota","39000":"State of Ohio","40000":"State of Oklahoma","41000":"State of Oregon","42000":"State of Pennsylvania","44000":"State of Rhode Island","45000":"State of South Carolina","46000":"State of South Dakota","47000":"State of Tennessee","48000":"State of Texas","49000":"State of Utah","50000":"State of Vermont","51000":"State of Virginia","53000":"State of Washington","54000":"State of West Virginia","55000":"State of Wisconsin","56000":"State of Wyoming","57000":"E N Pacific along U.S. WC from Canada to Mexico","58000":"N Pacific near Alaska along Alaska coastline, including Bering Sea and Gulf of Alaska","59000":"C Pacific including Hawaiian waters","60000":"American Samoa","61000":"SC Pacific including American Samoa waters","65000":"W Pacific including Mariana Islands waters","66000":"Guam","69000":"The Mariana Islands","72000":"Puerto Rico","73000":"W N Atlantic along U.S. EC, from Canada S to Currituck Beach Light, NC","75000":"W N Atlantic along U.S. EC S of Currituck Beach Light, NC, following coastline into Gulf of Mexico to Ocean Reef, FL, including Caribbean","77000":"Gulf of Mexico along the U.S. Gulf Coast from Mexico to Ocean Reef, FL","78000":"The Virgin Islands","91000":"Lake Superior","92000":"Lake Michigan","93000":"Lake Huron","94000":"Lake St. Clair","96000":"Lake Erie","97000":"Lake Ontario","98000":"St. Lawrence River above St. Regis"},"SUBDIV": {"0":"","1":"Northwest","2":"North","3":"Northeast","4":"West","5":"Central","6":"East","7":"Southwest","8":"South","9":"Southeast"},"ORGS": {"PEP":"A Primary Entry Point System","EAN":"The Emergency Action Network","CIV":"A Civil Authority","WXR":"The National Weather Service","EAS":"An EAS Participant"},"EVENTS": {"BZW":"a Blizzard Warning","AVW":"an Avalanche Warning","WFW":"a Wild Fire Warning","LSW":"a Land Slide Warning","SMW":"a Special Marine Warning","DSW":"a Dust Storm Warning","FSW":"a Flash Freeze Warning","FZW":"a Freeze Warning","EQW":"a Earthquake Warning","TSA":"a Tsunami Watch","FRW":"a Fire Warning","NAT":"a National Audible Test","VOA":"a Volcano Watch","TSW":"a Tsunami Warning","SPW":"a Shelter In Place Warning","EWW":"an Extreme Wind Warning","NPT":"a National Periodic Test","CAE":"a Child Abduction Emergency","TOE":"a 911 Telephone Outage Emergency","TXF":"a Transmitter Carrier Off","TOA":"a Tornado Watch","HUA":"a Hurricane Watch","EAN":"a National Emergency Action Notification","TRA":"a Tropical Storm Watch","LAE":"a Local Area Emergency","CEM":"a Civil Emergency Message","HMW":"a Hazardous Materials Warning","SQW":"a Snow Squall Warning","RHW":"a Radiological Hazard Warning","HWA":"a High Wind Watch","TOR":"a Tornado Warning","HUW":"a Hurricane Warning","RWT":"a Required Weekly Test","LEW":"a Law Enforcement Warning","NMN":"a Network Message Notification","HWW":"a High Wind Warning","VOW":"a Volcano Warning","SSA":"a Storm Surge Watch","EAT":"a National Emergency Action Termination","SSW":"a Storm Surge Warning","WSA":"a Winter Storm Watch","EVI":"an Immediate Evacuation","IFW":"an Industrial Fire Warning","ADR":"an Administrative Message","BLU":"a Blue Alert","EVA":"an Evacuation Watch","FLS":"a Flood Statement","TXB":"a Transmitter Backup On","SCS":"a School Closing Statement","CWW":"a Contaminated Water Warning","DMO":"a Practice/Demo Warning","HLS":"a Hurricane Statement","FFA":"a Flash Flood Watch","SPS":"a Special Weather Statement","FLW":"a Flood Warning","WSW":"a Winter Storm Warning","CHW":"a Chemical Hazard Warning","FLA":"a Flood Watch","DEW":"a Contagious Disease Warning","SVR":"a Severe Thunderstorm Warning","SVS":"a Severe Weather Statement","TRW":"a Tropical Storm Warning","IBW":"an Iceberg Warning","TXO":"a Transmitter Carrier On","FCW":"a Food Contamination Warning","RMT":"a Required Monthly Test","DBA":"a Dam Watch","NUW":"a Nuclear Plant Warning","WFA":"a Wild Fire Watch","BWW":"a Boil Water Warning","FFS":"a Flash Flood Statement","POS":"a Power Outage Statement","CFA":"a Coastal Flood Watch","FFW":"a Flash Flood Warning","CDW":"a Civil Danger Warning","BHW":"a Biological Hazard Warning","SVA":"a Severe Thunderstorm Watch","NIC":"a National Information Center","CFW":"a Coastal Flood Warning","NST":"a National Silent Test","AVA":"an Avalanche Watch","DBW":"a Dam Break Warning","TXP":"a Transmitter Primary On"}}"""

    def __init__(
        self, sameData: str, timeZone: int = None, mode: str = "NONE"
    ) -> None:
        sameData = (
            sameData.strip()
        )  ## Strip to get rid of leading / trailing newlines and spaces (You're welcome, Don / Kane.)
        stats = loads(self.__data__)
        self.FIPS = []
        self.FIPSText = []
        self.strFIPS = ""
        self.EASData = sameData

        ## CHECKING FOR VALID SAME
        if sameData == "":
            raise MissingSAME()
        elif sameData.startswith("NNNN"):
            self.EASText = "End Of Message"
            return
        elif not sameData.startswith("ZCZC"):
            raise InvalidSAME(sameData, message='"ZCZC" Start string missing')
        else:
            eas = "".join(
                sameData.replace("ZCZC-", "").replace("+", "-")
            ).split("-")
            eas.remove("")

            for i in eas[2:-3]:
                try:
                    assert len(i) == 6
                    assert self.__isInt__(i) == True
                    ## FIPS CODE
                    if i not in self.FIPS:
                        self.FIPS.append(str(i))
                except AssertionError:
                    raise InvalidSAME("Invalid codes in FIPS data")

            for i in sorted(self.FIPS):
                try:
                    subdiv = stats["SUBDIV"][i[0]]
                    same = stats["SAME"][i[1:]]
                    self.FIPSText.append(
                        f"{subdiv + ' ' if subdiv != '' else ''}{same}"
                    )
                except KeyError:
                    self.FIPSText.append(f"FIPS Code {i}")
                except Exception as E:
                    raise InvalidSAME(
                        self.FIPS, message=f"Error in FIPS Code ({str(E)})"
                    )
            if len(self.FIPSText) > 1:
                FIPSText = self.FIPSText
                FIPSText[-1] = f"and {FIPSText[-1]}"
            self.strFIPS = "; ".join(self.FIPSText).strip() + ";"

            ## TIME CODE
            try:
                self.purge = [eas[-3][:2], eas[-3][2:]]
            except IndexError:
                raise InvalidSAME(self.purge, message="Purge Time not HHMM.")
            self.timeStamp = eas[-2]
            utc = DT.utcnow()
            if timeZone == None:
                dtOffset = utc.timestamp() - DT.now().timestamp()
            else:
                dtOffset = -timeZone * 3600

            try:
                alertStartEpoch = (
                    DT.strptime(self.timeStamp, "%j%H%M")
                    .replace(year=utc.year)
                    .timestamp()
                )
            except ValueError:
                raise InvalidSAME(
                    self.timeStamp, message="Timestamp not JJJHHMM."
                )
            alertEndOffset = (int(self.purge[0]) * 3600) + (
                int(self.purge[1]) * 60
            )
            alertEndEpoch = alertStartEpoch + alertEndOffset

            try:
                self.startTime = DT.fromtimestamp(alertStartEpoch - dtOffset)
                self.endTime = DT.fromtimestamp(alertEndEpoch - dtOffset)
                if self.startTime.day == self.endTime.day:
                    self.startTimeText = self.startTime.strftime("%I:%M %p")
                    self.endTimeText = self.endTime.strftime("%I:%M %p")
                elif self.startTime.year == self.endTime.year:
                    self.startTimeText = self.startTime.strftime(
                        "%I:%M %p %B %d"
                    )
                    self.endTimeText = self.endTime.strftime("%I:%M %p %B %d")
                else:
                    self.startTimeText = self.startTime.strftime(
                        "%I:%M %p %B %d, %Y"
                    )
                    self.endTimeText = self.endTime.strftime(
                        "%I:%M %p %B %d, %Y"
                    )
            except Exception as E:
                raise InvalidSAME(
                    self.timeStamp,
                    message=f"Error in Time Conversion ({str(E)})",
                )

            ## ORG / EVENT CODE
            try:
                self.org = str(eas[0])
                self.evnt = str(eas[1])
                try:
                    assert len(eas[0]) == 3
                except AssertionError:
                    raise InvalidSAME("Originator is an invalid length")
                try:
                    assert len(eas[1]) == 3
                except AssertionError:
                    raise InvalidSAME("Event Code is an invalid length")
                try:
                    self.orgText = stats["ORGS"][self.org]
                except:
                    self.orgText = (
                        f"An Unknown Originator ({self.org}) has issued "
                    )
                try:
                    self.evntText = stats["EVENTS"][self.evnt]
                except:
                    self.evntText = f"an Unknown Event ({self.evnt})"
            except Exception as E:
                raise InvalidSAME(
                    [self.org, self.evnt],
                    message=f"Error in ORG / EVNT Decoding ({str(E)})",
                )

            ## CALLSIGN CODE"
            self.callsign = eas[-1].strip()

            ## FINAL TEXT
            if mode == "TFT":
                self.strFIPS = (
                    self.strFIPS[:-1]
                    .replace(",", "")
                    .replace(";", ",")
                    .replace("FIPS Code", "AREA")
                )
                self.startTimeText = self.startTime.strftime(
                    "%I:%M %p ON %b %d, %Y"
                )
                self.endTimeText = (
                    self.endTime.strftime("%I:%M %p")
                    if self.startTime.day == self.endTime.day
                    else self.endTime.strftime("%I:%M %p ON %b %d, %Y")
                )
                if self.org == "EAS" or self.evnt in ["NPT", "EAN"]:
                    self.EASText = f"{self.evntText} has been issued for the following counties/areas: {self.strFIPS} at {self.startTimeText} effective until {self.endTimeText}. message from {self.callsign}.".upper()
                else:
                    self.EASText = f"{self.orgText} has issued {self.evntText} for the following counties/areas: {self.strFIPS} at {self.startTimeText} effective until {self.endTimeText}. message from {self.callsign}.".upper()

            elif mode.startswith("SAGE"):
                if self.org == "CIV":
                    self.orgText = "The Civil Authorities"
                self.strFIPS = self.strFIPS[:-1].replace(";", ",")
                self.startTimeText = self.startTime.strftime(
                    "%I:%M %p"
                ).lower()
                self.endTimeText = self.endTime.strftime("%I:%M %p").lower()
                if self.startTime.day != self.endTime.day:
                    self.startTimeText += self.startTime.strftime(" %a %b %d")
                    self.endTimeText += self.endTime.strftime(" %a %b %d")
                if mode.endswith("DIGITAL"):
                    self.EASText = f"{self.orgText} {'have' if self.org == 'CIV' else 'has'} issued {self.evntText} for {self.strFIPS} beginning at {self.startTimeText} and ending at {self.endTimeText} ({self.callsign})"
                else:
                    if self.org == "EAS":
                        self.orgText = "A Broadcast station or cable system"
                    self.EASText = f"{self.orgText} {'have' if self.org == 'CIV' else 'has'} issued {self.evntText} for {self.strFIPS} beginning at {self.startTimeText} and ending at {self.endTimeText} ({self.callsign})"

            elif mode in ["TRILITHIC", "VIAVI", "EASY"]:
                self.strFIPS = (
                    self.strFIPS[:-1]
                    .replace(",", "")
                    .replace("; ", " - ")
                    .replace("and ", "")
                    if "000000" not in self.FIPS
                    else "The United States"
                )
                if self.strFIPS == "The United States":
                    bigFips = "for"
                else:
                    bigFips = "for the following counties:"
                self.startTimeText = ""
                self.endTimeText = self.endTime.strftime(
                    "%m/%d/%y %H:%M:00 "
                ) + self.getTZ(dtOffset)
                if self.org == "CIV":
                    self.orgText = "Civil Authorities"
                self.EASText = f"{self.orgText} {'have' if self.org == 'CIV' else 'has'} issued {self.evntText} {bigFips} {self.strFIPS}. Effective Until {self.endTimeText}. ({self.callsign})"

            elif mode in ["BURK"]:
                if self.org == "EAS":
                    self.orgText = "A Broadcast station or cable system"
                elif self.org == "CIV":
                    self.orgText = "Civil Authorities"
                elif self.org == "WXR":
                    self.orgText = "National Weather Service"
                self.strFIPS = (
                    self.strFIPS[:-1].replace(",", "").replace(";", ",")
                )
                self.startTimeText = (
                    self.startTime.strftime("%B %d, %Y").upper()
                    + " at "
                    + self.startTime.strftime("%I:%M %p")
                )
                self.endTimeText = self.endTime.strftime("%I:%M %p, %B %d, %Y")
                self.evntText = " ".join(self.evntText.split(" ")[1:]).upper()
                self.EASText = f"{self.orgText} has issued {self.evntText} for the following counties/areas: {self.strFIPS} on {self.startTimeText} effective until {self.endTimeText}."

            elif mode in ["DAS", "DASDEC", "MONROE"]:
                self.orgText = self.orgText.upper()
                self.evntText = self.evntText.upper()
                self.startTimeText = self.startTime.strftime(
                    "%I:%M %p ON %b %d, %Y"
                ).upper()
                self.endTimeText = self.endTime.strftime(
                    "%I:%M %p %b %d, %Y"
                ).upper()
                self.EASText = f"{self.orgText} HAS ISSUED {self.evntText} FOR THE FOLLOWING COUNTIES/AREAS: {self.strFIPS} AT {self.startTimeText} EFFECTIVE UNTIL {self.endTimeText}. MESSAGE FROM {self.callsign.upper()}."

            else:
                self.EASText = f"{self.orgText} has issued {self.evntText} for {self.strFIPS} beginning at {self.startTimeText} and ending at {self.endTimeText}. Message from {self.callsign}."

    @classmethod
    def __isInt__(cls, number):
        try:
            int(number)
        except ValueError:
            return False
        else:
            return True

    @classmethod
    def getTZ(cls, tzOffset):
        tzone = int(tzOffset / 3600.0)
        locTime = localtime().tm_isdst
        TMZ = "UTC"
        if tzone == 3 and locTime > 0:
            TMZ = "ADT"
        elif tzone == 4:
            TMZ = "AST"
            if locTime > 0:
                TMZ = "EDT"
        elif tzone == 5:
            TMZ = "EST"
            if locTime > 0:
                TMZ = "CDT"
        elif tzone == 6:
            TMZ = "CST"
            if locTime > 0:
                TMZ = "MDT"
        elif tzone == 7:
            TMZ = "MST"
            if locTime > 0:
                TMZ = "PDT"
        elif tzone == 8:
            TMZ = "PST"
        return TMZ
